@@ -21,9 +21,7 @@ __copyright__ = f"Copyright (c) 2018-{time.strftime('%Y')}, {__author__}."
 __homepage__ = "https://github.com/Lightning-AI/lightning"
 __docs_url__ = "https://lightning.ai/docs/pytorch/stable/"
 # this has to be simple string, see: https://github.com/pypa/twine/issues/522
-__docs__ = (
-    "Use Lightning Apps to build everything from production-ready, multi-cloud ML systems to simple research demos."
-)
+__docs__ = "The Deep Learning framework to train, deploy, and ship AI products Lightning fast."
 __long_doc__ = """
 What is it?
 -----------
