@@ -1,6 +1,5 @@
 """Root package info."""
 import logging
-import os
 
 # explicitly don't set root logger's propagation and leave this to subpackages to manage
 _logger = logging.getLogger(__name__)
@@ -19,7 +18,6 @@ from lightning.app import storage  # noqa: E402
 from lightning.app.core.app import LightningApp  # noqa: E402
 from lightning.app.core.flow import LightningFlow  # noqa: E402
 from lightning.app.core.work import LightningWork  # noqa: E402
-from lightning.app.perf import pdb  # noqa: E402
 from lightning.app.utilities.packaging.build_config import BuildConfig  # noqa: E402
 from lightning.app.utilities.packaging.cloud_compute import CloudCompute  # noqa: E402
 from lightning.fabric.fabric import Fabric  # noqa: E402
@@ -28,12 +26,8 @@ from lightning.pytorch.callbacks import Callback  # noqa: E402
 from lightning.pytorch.core import LightningDataModule, LightningModule  # noqa: E402
 from lightning.pytorch.trainer import Trainer  # noqa: E402
 
-import lightning.app  # isort: skip # noqa: E402
+import lightning.app  # isort: skip # noqa: E402, F401
 
-lightning.app._PROJECT_ROOT = os.path.dirname(lightning.app._PROJECT_ROOT)
-
-# Enable breakpoint within forked processes.
-__builtins__["breakpoint"] = pdb.set_trace
 
 __all__ = [
     "LightningApp",
@@ -48,5 +42,4 @@ __all__ = [
     "seed_everything",
     "Fabric",
     "storage",
-    "pdb",
 ]
