@@ -29,21 +29,28 @@ _ASSISTANT = _load_py_module(name="assistant", location=os.path.join(_PROJECT_RO
 def _prepare_extras() -> Dict[str, Any]:
     # https://setuptools.readthedocs.io/en/latest/setuptools.html#declaring-extras
     # Define package extras. These are only installed if you specify them.
-    # From remote, use like `pip install pytorch-lightning[dev, docs]`
+    # From remote, use like `pip install "lightning[dev, docs]"`
     # From local copy of repo, use like `pip install ".[dev, docs]"`
     req_files = [Path(p) for p in glob.glob(os.path.join(_PATH_REQUIREMENTS, "*", "*.txt"))]
-    common_args = dict(unfreeze="none" if _FREEZE_REQUIREMENTS else "major")
+    common_args = {"unfreeze": "none" if _FREEZE_REQUIREMENTS else "major"}
+    # per-project extras
     extras = {
         f"{p.parent.name}-{p.stem}": _ASSISTANT.load_requirements(file_name=p.name, path_dir=p.parent, **common_args)
         for p in req_files
-        if p.name not in ("docs.txt", "devel.txt", "base.txt") and not p.parts[-2].startswith("_")
+        if p.name not in ("docs.txt", "base.txt") and not p.parent.name.startswith("_")
     }
+    # project specific extras groups
+    extras["fabric-all"] = extras["fabric-strategies"] + extras["fabric-examples"]
+    extras["fabric-dev"] = extras["fabric-all"] + extras["fabric-test"]
+    extras["pytorch-all"] = extras["pytorch-extra"] + extras["pytorch-strategies"] + extras["pytorch-examples"]
+    extras["pytorch-dev"] = extras["pytorch-all"] + extras["pytorch-test"]
+    extras["app-extra"] = extras["app-cloud"] + extras["app-ui"] + extras["app-components"]
+    extras["app-all"] = extras["app-extra"]
+    extras["app-dev"] = extras["app-all"] + extras["app-test"]
+    # merge per-project extras of the same category, e.g. `app-test` + `fabric-test`
     for extra in list(extras):
         name = "-".join(extra.split("-")[1:])
         extras[name] = extras.get(name, []) + extras[extra]
-    extras["extra"] += extras["cloud"] + extras["ui"] + extras["components"]
-    extras["all"] = extras["extra"]
-    extras["dev"] = extras["all"] + extras["test"]  # + extras['docs']
     extras = {name: sorted(set(reqs)) for name, reqs in extras.items()}
     print("The extras are: ", extras)
     return extras
@@ -64,37 +71,37 @@ def _setup_args() -> Dict[str, Any]:
         _PATH_REQUIREMENTS, unfreeze="none" if _FREEZE_REQUIREMENTS else "major"
     ) + ["pytorch-lightning"]
 
-    return dict(
-        name="lightning",
-        version=version.version,
-        description=about.__docs__,
-        author=about.__author__,
-        author_email=about.__author_email__,
-        url=about.__homepage__,
-        download_url="https://github.com/Lightning-AI/lightning",
-        license=about.__license__,
-        packages=find_packages(where="src", include=["lightning", "lightning.*"]),
-        package_dir={"": "src"},
-        long_description=long_description,
-        long_description_content_type="text/markdown",
-        include_package_data=True,
-        zip_safe=False,
-        keywords=["deep learning", "pytorch", "AI"],  # todo: aggregate tags from all packages
-        python_requires=">=3.8",  # todo: take the lowes based on all packages
-        entry_points={
+    return {
+        "name": "lightning",
+        "version": version.version,
+        "description": about.__docs__,
+        "author": about.__author__,
+        "author_email": about.__author_email__,
+        "url": about.__homepage__,
+        "download_url": "https://github.com/Lightning-AI/lightning",
+        "license": about.__license__,
+        "packages": find_packages(where="src", include=["lightning", "lightning.*"]),
+        "package_dir": {"": "src"},
+        "long_description": long_description,
+        "long_description_content_type": "text/markdown",
+        "include_package_data": True,
+        "zip_safe": False,
+        "keywords": ["deep learning", "pytorch", "AI"],  # todo: aggregate tags from all packages
+        "python_requires": ">=3.8",  # todo: take the lowes based on all packages
+        "entry_points": {
             "console_scripts": [
                 "lightning = lightning.app.cli.lightning_cli:main",
             ],
         },
-        setup_requires=[],
-        install_requires=install_requires,
-        extras_require=_prepare_extras(),
-        project_urls={
+        "setup_requires": [],
+        "install_requires": install_requires,
+        "extras_require": _prepare_extras(),
+        "project_urls": {
             "Bug Tracker": "https://github.com/Lightning-AI/lightning/issues",
             "Documentation": "https://lightning.ai/lightning-docs",
             "Source Code": "https://github.com/Lightning-AI/lightning",
         },
-        classifiers=[
+        "classifiers": [
             "Environment :: Console",
             "Natural Language :: English",
             # How mature is this project? Common values are
@@ -113,4 +120,4 @@ def _setup_args() -> Dict[str, Any]:
             "Programming Language :: Python :: 3.9",
             "Programming Language :: Python :: 3.10",
         ],  # todo: consider aggregation/union of tags from particular packages
-    )
+    }
