@@ -50,8 +50,8 @@ def _get_device():
 
     if _TORCH_GREATER_EQUAL_1_12 and torch.backends.mps.is_available() and platform.processor() in ("arm", "arm64"):
         return torch.device("mps", local_rank)
-    else:
-        return torch.device(f"cuda:{local_rank}" if torch.cuda.is_available() else "cpu")
+
+    return torch.device(f"cuda:{local_rank}" if torch.cuda.is_available() else "cpu")
 
 
 class _DefaultInputData(BaseModel):
@@ -211,6 +211,7 @@ class PythonServer(LightningWork, abc.ABC):
             ...         return {"prediction": self._model(request.image)}
             ...
             >>> app = LightningApp(SimpleServer())
+
         """
         super().__init__(parallel=True, **kwargs)
         if not issubclass(input_type, BaseModel):
@@ -228,6 +229,7 @@ class PythonServer(LightningWork, abc.ABC):
 
         Note that this will be called exactly once on every work machines. So if you have multiple machines for serving,
         this will be called on each of them.
+
         """
         return
 
@@ -243,6 +245,7 @@ class PythonServer(LightningWork, abc.ABC):
 
         This method must be overriden by the user with the prediction logic. The pre/post processing, actual prediction
         using the model(s) etc goes here
+
         """
         pass
 
@@ -296,7 +299,7 @@ class PythonServer(LightningWork, abc.ABC):
             logger.warn(
                 "Some dependencies to run the UI are missing. To resolve, run `pip install lightning-api-access`"
             )
-            return
+            return None
 
         class_name = self.__class__.__name__
         url = f"{self.url}/predict"
@@ -325,6 +328,7 @@ class PythonServer(LightningWork, abc.ABC):
         """Run method takes care of configuring and setting up a FastAPI server behind the scenes.
 
         Normally, you don't need to override this method.
+
         """
         self.setup(*args, **kwargs)
 
