@@ -33,6 +33,8 @@ from lightning.app.utilities.load_app import _load_plugin_from_file
 
 logger = Logger(__name__)
 
+_PLUGIN_MAX_CLIENT_TRIES: int = 3
+
 
 class LightningPlugin:
     """A ``LightningPlugin`` is a single-file Python class that can be executed within a cloudspace to perform
@@ -42,6 +44,7 @@ class LightningPlugin:
         self.project_id = ""
         self.cloudspace_id = ""
         self.cluster_id = ""
+        self.source_app = ""
 
     def run(self, *args: str, **kwargs: str) -> Optional[List[_Action]]:
         """Override with the logic to execute on the cloudspace."""
@@ -57,9 +60,13 @@ class LightningPlugin:
 
         Returns:
             The relative URL of the created job.
+
         """
+        from lightning.app.runners.backends.cloud import CloudBackend
         from lightning.app.runners.cloud import CloudRuntime
 
+        logger.info(f"Processing job run request. name: {name}, app_entrypoint: {app_entrypoint}, env_vars: {env_vars}")
+
         # Dispatch the job
         _set_flow_context()
 
@@ -76,6 +83,7 @@ class LightningPlugin:
             env_vars=env_vars,
             secrets={},
             run_app_comment_commands=True,
+            backend=CloudBackend(entrypoint_file, client_max_tries=_PLUGIN_MAX_CLIENT_TRIES),
         )
         # Used to indicate Lightning has been dispatched
         os.environ["LIGHTNING_DISPATCHED"] = "1"
@@ -85,6 +93,7 @@ class LightningPlugin:
             cloudspace_id=self.cloudspace_id,
             name=name,
             cluster_id=self.cluster_id,
+            source_app=self.source_app,
         )
         # Return a relative URL so it can be used with the NavigateTo action.
         return url.replace(constants.get_lightning_cloud_url(), "")
@@ -94,7 +103,9 @@ class LightningPlugin:
         project_id: str,
         cloudspace_id: str,
         cluster_id: str,
+        source_app: str,
     ) -> None:
+        self.source_app = source_app
         self.project_id = project_id
         self.cloudspace_id = cloudspace_id
         self.cluster_id = cluster_id
@@ -107,6 +118,7 @@ class _Run(BaseModel):
     cloudspace_id: str
     cluster_id: str
     plugin_arguments: Dict[str, str]
+    source_app: str
 
 
 def _run_plugin(run: _Run) -> Dict[str, Any]:
@@ -118,6 +130,8 @@ def _run_plugin(run: _Run) -> Dict[str, Any]:
 
         # Download the tarball
         try:
+            logger.info(f"Downloading plugin source: {run.source_code_url}")
+
             # Sometimes the URL gets encoded, so we parse it here
             source_code_url = urlparse(run.source_code_url).geturl()
 
@@ -128,28 +142,32 @@ def _run_plugin(run: _Run) -> Dict[str, Any]:
 
             with open(download_path, "wb") as f:
                 f.write(response.content)
-        except Exception as e:
+        except Exception as ex:
             raise HTTPException(
                 status_code=status.HTTP_500_INTERNAL_SERVER_ERROR,
-                detail=f"Error downloading plugin source: {str(e)}.",
+                detail=f"Error downloading plugin source: {str(ex)}.",
             )
 
         # Extract
         try:
+            logger.info("Extracting plugin source.")
+
             with tarfile.open(download_path, "r:gz") as tf:
                 tf.extractall(source_path)
-        except Exception as e:
+        except Exception as ex:
             raise HTTPException(
                 status_code=status.HTTP_500_INTERNAL_SERVER_ERROR,
-                detail=f"Error extracting plugin source: {str(e)}.",
+                detail=f"Error extracting plugin source: {str(ex)}.",
             )
 
         # Import the plugin
         try:
+            logger.info(f"Importing plugin: {run.plugin_entrypoint}")
+
             plugin = _load_plugin_from_file(os.path.join(source_path, run.plugin_entrypoint))
-        except Exception as e:
+        except Exception as ex:
             raise HTTPException(
-                status_code=status.HTTP_500_INTERNAL_SERVER_ERROR, detail=f"Error loading plugin: {str(e)}."
+                status_code=status.HTTP_500_INTERNAL_SERVER_ERROR, detail=f"Error loading plugin: {str(ex)}."
             )
 
         # Ensure that apps are dispatched from the temp directory
@@ -158,16 +176,22 @@ def _run_plugin(run: _Run) -> Dict[str, Any]:
 
         # Setup and run the plugin
         try:
+            logger.info(
+                "Running plugin. "
+                f"project_id: {run.project_id}, cloudspace_id: {run.cloudspace_id}, cluster_id: {run.cluster_id}."
+            )
+
             plugin._setup(
                 project_id=run.project_id,
                 cloudspace_id=run.cloudspace_id,
                 cluster_id=run.cluster_id,
+                source_app=run.source_app,
             )
             actions = plugin.run(**run.plugin_arguments) or []
             return {"actions": [action.to_spec().to_dict() for action in actions]}
-        except Exception as e:
+        except Exception as ex:
             raise HTTPException(
-                status_code=status.HTTP_500_INTERNAL_SERVER_ERROR, detail=f"Error running plugin: {str(e)}."
+                status_code=status.HTTP_500_INTERNAL_SERVER_ERROR, detail=f"Error running plugin: {str(ex)}."
             )
         finally:
             os.chdir(cwd)
