@@ -81,9 +81,14 @@ class CloudCompute:
 
         mounts: External data sources which should be mounted into a work as a filesystem at runtime.
 
+        colocation_group_id: Identifier for groups of works to be colocated in the same datacenter.
+            Set this to a string of max. 64 characters and all works with this group id will run in the same datacenter.
+            If not set, the works are not guaranteed to be colocated.
+
         interruptible: Whether to run on a interruptible machine e.g the machine can be stopped
             at any time by the providers. This is also known as spot or preemptible machines.
             Compared to on-demand machines, they tend to be cheaper.
+
     """
 
     name: str = "default"
@@ -91,6 +96,7 @@ class CloudCompute:
     idle_timeout: Optional[int] = None
     shm_size: Optional[int] = None
     mounts: Optional[Union[Mount, List[Mount]]] = None
+    colocation_group_id: Optional[str] = None
     interruptible: bool = False
     _internal_id: Optional[str] = None
 
@@ -111,6 +117,11 @@ class CloudCompute:
             if "gpu" not in self.name:
                 raise ValueError("CloudCompute `interruptible=True` is supported only with GPU.")
 
+        # FIXME: Clean the mess on the platform side
+        if self.name == "default" or self.name == "cpu":
+            self.name = "cpu-small"
+            self._internal_id = "default"
+
         # TODO: Remove from the platform first.
         self.preemptible = self.interruptible
 
@@ -118,6 +129,12 @@ class CloudCompute:
         if self._internal_id is None:
             self._internal_id = self._generate_id()
 
+        if self.colocation_group_id is not None and (
+            not isinstance(self.colocation_group_id, str)
+            or (isinstance(self.colocation_group_id, str) and len(self.colocation_group_id) > 64)
+        ):
+            raise ValueError("colocation_group_id can only be a string of maximum 64 characters.")
+
     def to_dict(self) -> dict:
         _verify_mount_root_dirs_are_unique(self.mounts)
         return {"type": __CLOUD_COMPUTE_IDENTIFIER__, **asdict(self)}
@@ -147,7 +164,7 @@ class CloudCompute:
         return self._internal_id
 
     def is_default(self) -> bool:
-        return self.name == "default"
+        return self.name in ("default", "cpu-small")
 
     def _generate_id(self):
         return "default" if self.name == "default" else uuid4().hex[:7]
@@ -166,7 +183,6 @@ def _verify_mount_root_dirs_are_unique(mounts: Union[None, Mount, List[Mount], T
 
 
 def _maybe_create_cloud_compute(state: Dict) -> Union[CloudCompute, Dict]:
-    if state and __CLOUD_COMPUTE_IDENTIFIER__ == state.get("type", None):
-        cloud_compute = CloudCompute.from_dict(state)
-        return cloud_compute
+    if state and state.get("type", None) == __CLOUD_COMPUTE_IDENTIFIER__:
+        return CloudCompute.from_dict(state)
     return state
