@@ -43,10 +43,17 @@ from lightning.fabric.utilities.data import (
     has_iterable_dataset,
 )
 from lightning.fabric.utilities.distributed import DistributedSamplerWrapper
+from lightning.fabric.utilities.registry import _load_external_callbacks
 from lightning.fabric.utilities.seed import seed_everything
 from lightning.fabric.utilities.types import ReduceOp
 from lightning.fabric.utilities.warnings import PossibleUserWarning
-from lightning.fabric.wrappers import _FabricDataLoader, _FabricModule, _FabricOptimizer, _unwrap_objects
+from lightning.fabric.wrappers import (
+    _FabricDataLoader,
+    _FabricModule,
+    _FabricOptimizer,
+    _unwrap_compiled,
+    _unwrap_objects,
+)
 
 
 class Fabric:
@@ -74,6 +81,7 @@ class Fabric:
             can be invoked through :meth:`~lightning.fabric.fabric.Fabric.call` by the user.
         loggers: A single logger or a list of loggers. See :meth:`~lightning.fabric.fabric.Fabric.log` for more
             information.
+
     """
 
     def __init__(
@@ -99,8 +107,7 @@ class Fabric:
         self._strategy: Strategy = self._connector.strategy
         self._accelerator: Accelerator = self._connector.accelerator
         self._precision: Precision = self._strategy.precision
-        callbacks = callbacks if callbacks is not None else []
-        self._callbacks = callbacks if isinstance(callbacks, list) else [callbacks]
+        self._callbacks = self._configure_callbacks(callbacks)
         loggers = loggers if loggers is not None else []
         self._loggers = loggers if isinstance(loggers, list) else [loggers]
         self._models_setup: int = 0
@@ -124,6 +131,7 @@ class Fabric:
         """The current device this process runs on.
 
         Use this to create tensors directly on the device if needed.
+
         """
         return self._strategy.root_device
 
@@ -166,6 +174,7 @@ class Fabric:
         """All the code inside this run method gets accelerated by Fabric.
 
         You can pass arbitrary arguments to this function when overriding it.
+
         """
 
     def setup(
@@ -184,6 +193,7 @@ class Fabric:
 
         Returns:
             The tuple containing wrapped module and the optimizers, in the same order they were passed in.
+
         """
         self._validate_setup(module, optimizers)
         original_module = module
@@ -204,9 +214,12 @@ class Fabric:
         module = _FabricModule(module, self._precision, original_module=original_module)
 
         # Update the _DeviceDtypeModuleMixin's device parameter
-        module.to(self.device if move_to_device else next(module.parameters()).device)
+        module.to(self.device if move_to_device else next(module.parameters(), torch.tensor(0)).device)
 
-        optimizers = [_FabricOptimizer(optimizer=optimizer, strategy=self._strategy) for optimizer in optimizers]
+        optimizers = [
+            _FabricOptimizer(optimizer=optimizer, strategy=self._strategy, callbacks=self._callbacks)
+            for optimizer in optimizers
+        ]
 
         self._models_setup += 1
 
@@ -214,9 +227,11 @@ class Fabric:
             original_module._fabric = self  # type: ignore[assignment]
             original_module._fabric_optimizers = optimizers  # type: ignore[assignment]
 
+        self.call("on_after_setup", fabric=self, module=module)
+
         if optimizers:
             # join both types in a tuple for API convenience
-            return tuple((module, *optimizers))
+            return (module, *optimizers)
         return module
 
     def setup_module(self, module: nn.Module, move_to_device: bool = True) -> _FabricModule:
@@ -233,6 +248,7 @@ class Fabric:
 
         Returns:
             The wrapped model.
+
         """
         self._validate_setup_module(module)
         original_module = module
@@ -248,7 +264,7 @@ class Fabric:
 
         if not isinstance(self._strategy, FSDPStrategy):
             # Update the _DeviceDtypeModuleMixin's device parameter
-            module.to(self.device if move_to_device else next(module.parameters()).device)
+            module.to(self.device if move_to_device else next(module.parameters(), torch.tensor(0)).device)
 
         if hasattr(original_module, "_fabric"):  # this is probably a LightningModule
             original_module._fabric = self  # type: ignore[assignment]
@@ -267,10 +283,14 @@ class Fabric:
 
         Returns:
             The wrapped optimizer(s).
+
         """
         self._validate_setup_optimizers(optimizers)
         optimizers = [self._strategy.setup_optimizer(optimizer) for optimizer in optimizers]
-        optimizers = [_FabricOptimizer(optimizer=optimizer, strategy=self._strategy) for optimizer in optimizers]
+        optimizers = [
+            _FabricOptimizer(optimizer=optimizer, strategy=self._strategy, callbacks=self._callbacks)
+            for optimizer in optimizers
+        ]
         return optimizers[0] if len(optimizers) == 1 else tuple(optimizers)
 
     def setup_dataloaders(
@@ -290,6 +310,7 @@ class Fabric:
 
         Returns:
             The wrapped dataloaders, in the same order they were passed in.
+
         """
         self._validate_setup_dataloaders(dataloaders)
         dataloaders = [
@@ -317,6 +338,7 @@ class Fabric:
 
         Returns:
             The wrapped dataloader.
+
         """
         sampler = dataloader.sampler
         if use_distributed_sampler and self._requires_distributed_sampler(dataloader):
@@ -385,6 +407,7 @@ class Fabric:
             norm_type: The type of norm if `max_norm` was passed. Can be ``'inf'`` for infinity norm.
                 Default is the 2-norm.
             error_if_nonfinite: An error is raised if the total norm of the gradients is NaN or infinite.
+
         """
         if clip_val is not None and max_norm is not None:
             raise ValueError(
@@ -394,7 +417,7 @@ class Fabric:
         if clip_val is not None:
             self.strategy.clip_gradients_value(_unwrap_objects(module), _unwrap_objects(optimizer), clip_val=clip_val)
             return None
-        elif max_norm is not None:
+        if max_norm is not None:
             return self.strategy.clip_gradients_norm(
                 _unwrap_objects(module),
                 _unwrap_objects(optimizer),
@@ -410,6 +433,7 @@ class Fabric:
 
         Use this only if the `forward` method of your model does not cover all operations you wish to run with the
         chosen precision setting.
+
         """
         with self._precision.forward_context():
             yield
@@ -447,6 +471,7 @@ class Fabric:
         """Print something only on the first process.
 
         Arguments passed to this method are forwarded to the Python built-in :func:`print` function.
+
         """
         if self.local_rank == 0:
             print(*args, **kwargs)
@@ -457,6 +482,7 @@ class Fabric:
         Use this to synchronize all parallel processes, but only if necessary, otherwise the overhead of synchronization
         will cause your program to slow down. This method needs to be called on all processes. Failing to do so will
         cause your program to stall forever.
+
         """
         self._strategy.barrier(name=name)
 
@@ -472,6 +498,7 @@ class Fabric:
 
         Return:
             The transferred data, the same value on every rank.
+
         """
         return self._strategy.broadcast(obj, src=src)
 
@@ -490,6 +517,7 @@ class Fabric:
         Return:
             A tensor of shape (world_size, batch, ...), or if the input was a collection
             the output will also be a collection with tensors of this shape.
+
         """
         group = group if group is not None else torch.distributed.group.WORLD
         data = convert_to_tensors(data, device=self.device)
@@ -503,10 +531,13 @@ class Fabric:
     ) -> Union[Tensor, Dict, List, Tuple]:
         """Reduce tensors or collections of tensors from multiple processes.
 
-        This method needs to be called on all processes. Failing to do so will cause your program to stall forever.
+        The reduction on tensors is applied in-place, meaning the result will be placed back into the input tensor.
+        This method needs to be called on all processes and the tensors need to have the same shape across all
+        processes, otherwise your program will stall forever.
 
         Args:
-            data: int, float, tensor of shape (batch, ...), or a (possibly nested) collection thereof.
+            data: int, float, tensor of shape (batch, ...), or a (possibly nested) collection thereof. Tensor will be
+                modified in-place.
             group: the process group to reduce results across. Defaults to all processes (world).
             reduce_op: the reduction operation. Defaults to 'mean'. Can also be a string 'sum' or ReduceOp.
                 Some strategies may limit the choices here.
@@ -514,6 +545,7 @@ class Fabric:
         Return:
             A tensor of the same shape as the input with values reduced pointwise across processes. The same is
             applied to tensors in a collection if a collection is given as input.
+
         """
         group = group if group is not None else torch.distributed.group.WORLD
         data = convert_to_tensors(data, device=self.device)
@@ -541,14 +573,15 @@ class Fabric:
             module: The module for which to control the gradient synchronization.
             enabled: Whether the context manager is enabled or not. ``True`` means skip the sync, ``False`` means do not
                 skip.
-        """
 
+        """
+        module = _unwrap_compiled(module)
         if not isinstance(module, _FabricModule):
             raise TypeError(
                 "You need to set up the model first before you can call `self.no_backward_sync()`:"
                 " `model = self.setup(model, ...)`"
             )
-        if not enabled or isinstance(self._strategy, SingleDeviceStrategy):
+        if not enabled or isinstance(self._strategy, (SingleDeviceStrategy, XLAStrategy)):
             context = nullcontext()
         elif self._strategy._backward_sync_control is None:
             rank_zero_warn(
@@ -577,6 +610,7 @@ class Fabric:
                 model = MyModel()
 
         The context manager is strategy-agnostic and for the ones that don't do sharding, it is a no-op.
+
         """
         if isinstance(self._strategy, _Sharded):
             with self._strategy.module_sharded_context():
@@ -594,6 +628,7 @@ class Fabric:
             path: A path to where the file(s) should be saved
             state: A dictionary with contents to be saved. If the dict contains modules or optimizers, their
                 state-dict will be retrieved and converted automatically.
+
         """
         return self._strategy.save_checkpoint(path=path, state=_unwrap_objects(state))
 
@@ -612,6 +647,7 @@ class Fabric:
         Returns:
             The remaining items that were not restored into the given state dictionary. If no state dictionary is
             given, the full checkpoint will be returned.
+
         """
         return self._strategy.load_checkpoint(path=path, state=state)
 
@@ -633,6 +669,7 @@ class Fabric:
         ``launch()`` from your code.
 
         ``launch()`` is a no-op when called multiple times and no function is passed in.
+
         """
         if _is_using_cli():
             raise RuntimeError(
@@ -669,6 +706,7 @@ class Fabric:
 
             fabric = Fabric(callbacks=[MyCallback()])
             fabric.call("on_train_epoch_end", results={...})
+
         """
         for callback in self._callbacks:
             method = getattr(callback, hook_name, None)
@@ -697,6 +735,7 @@ class Fabric:
                 graph automatically.
             step: Optional step number. Most Logger implementations auto-increment the step value by one with every
                 log call. You can specify your own value here.
+
         """
         self.log_dict(metrics={name: value}, step=step)
 
@@ -708,6 +747,7 @@ class Fabric:
                 Any :class:`torch.Tensor` in the dictionary get detached from the graph automatically.
             step: Optional step number. Most Logger implementations auto-increment this value by one with every
                 log call. You can specify your own value here.
+
         """
         metrics = convert_tensors_to_scalars(metrics)
         for logger in self._loggers:
@@ -718,6 +758,7 @@ class Fabric:
         """Helper function to seed everything without explicitly importing Lightning.
 
         See :func:`lightning.fabric.utilities.seed.seed_everything` for more details.
+
         """
         if workers is None:
             # Lightning sets `workers=False` by default to avoid breaking reproducibility, but since this is a new
@@ -729,8 +770,7 @@ class Fabric:
         run_method = partial(self._run_with_setup, run_method)
         if self._strategy.launcher is not None:
             return self._strategy.launcher.launch(run_method, *args, **kwargs)
-        else:
-            return run_method(*args, **kwargs)
+        return run_method(*args, **kwargs)
 
     def _run_with_setup(self, run_function: Callable, *args: Any, **kwargs: Any) -> Any:
         self._strategy.setup_environment()
@@ -741,14 +781,28 @@ class Fabric:
             return run_function(*args, **kwargs)
 
     def _move_model_to_device(self, model: nn.Module, optimizers: List[Optimizer]) -> nn.Module:
-        initial_device = next(model.parameters()).device
-        if any(param.device != initial_device for param in model.parameters()):
-            rank_zero_warn(
-                "The model passed to `Fabric.setup()` has parameters on different devices. Since `move_to_device=True`,"
-                " all parameters will be moved to the new device. If this is not desired, set "
-                " `Fabric.setup(..., move_to_device=False)`.",
-                category=PossibleUserWarning,
-            )
+        try:
+            initial_name, initial_param = next(model.named_parameters())
+        except StopIteration:
+            pass
+        else:
+            initial_device = initial_param.device
+            count = 0
+            first_name, first_device = None, None
+            for name, param in model.named_parameters():
+                if param.device != initial_device:
+                    count += 1
+                    if first_name is None:
+                        first_name = name
+                        first_device = param.device
+            if count > 0:
+                rank_zero_warn(
+                    f"The model passed to `Fabric.setup()` has {count} parameters on different devices (for example"
+                    f" {first_name!r} on {first_device} and {initial_name!r} on {initial_device}). Since"
+                    " `move_to_device=True`, all parameters will be moved to the new device. If this is not"
+                    " desired, set `Fabric.setup(..., move_to_device=False)`.",
+                    category=PossibleUserWarning,
+                )
 
         if isinstance(self._strategy, XLAStrategy):
             # When the user creates the optimizer, they reference the parameters on the CPU.
@@ -833,6 +887,13 @@ class Fabric:
         if any(not isinstance(dl, DataLoader) for dl in dataloaders):
             raise TypeError("Only PyTorch DataLoader are currently supported in `setup_dataloaders`.")
 
+    @staticmethod
+    def _configure_callbacks(callbacks: Optional[Union[List[Any], Any]]) -> List[Any]:
+        callbacks = callbacks if callbacks is not None else []
+        callbacks = callbacks if isinstance(callbacks, list) else [callbacks]
+        callbacks.extend(_load_external_callbacks("lightning.fabric.callbacks_factory"))
+        return callbacks
+
 
 def _is_using_cli() -> bool:
     return bool(int(os.environ.get("LT_CLI_USED", "0")))
