@@ -54,8 +54,8 @@ class SingleDeviceStrategy(Strategy):
         module.to(self.root_device)
 
     def all_reduce(self, tensor: Any | Tensor, *args: Any, **kwargs: Any) -> Any | Tensor:
-        """Reduces a tensor from several distributed processes to one aggregated tensor. As this plugin only
-        operates with a single device, the reduction is simply the identity.
+        """Reduces a tensor from several distributed processes to one aggregated tensor. As this plugin only operates
+        with a single device, the reduction is simply the identity.
 
         Args:
             tensor: the tensor to sync and reduce
@@ -64,6 +64,7 @@ class SingleDeviceStrategy(Strategy):
 
         Return:
             the unmodified input as reduction is not needed for single process operation
+
         """
         return tensor
 
