@@ -14,7 +14,7 @@
 """General utilities."""
 
 from lightning.fabric.utilities.apply_func import move_data_to_device  # noqa: F401
-from lightning.fabric.utilities.enums import _AcceleratorType, LightningEnum  # noqa: F401
+from lightning.fabric.utilities.enums import LightningEnum  # noqa: F401
 from lightning.fabric.utilities.rank_zero import (  # noqa: F401
     rank_zero_deprecation,
     rank_zero_info,
