@@ -42,9 +42,7 @@ def _determine_root_gpu_device(gpus: List[_DEVICE]) -> Optional[_DEVICE]:
     assert len(gpus) > 0, "GPUs should be a non-empty list"
 
     # set root gpu
-    root_gpu = gpus[0]
-
-    return root_gpu
+    return gpus[0]
 
 
 def _parse_gpu_ids(
@@ -115,8 +113,8 @@ def _normalize_parse_gpu_string_input(s: Union[int, str, List[int]]) -> Union[in
 
 
 def _sanitize_gpu_ids(gpus: List[int], include_cuda: bool = False, include_mps: bool = False) -> List[int]:
-    """Checks that each of the GPUs in the list is actually available. Raises a MisconfigurationException if any of
-    the GPUs is not available.
+    """Checks that each of the GPUs in the list is actually available. Raises a MisconfigurationException if any of the
+    GPUs is not available.
 
     Args:
         gpus: List of ints corresponding to GPU indices
@@ -127,6 +125,7 @@ def _sanitize_gpu_ids(gpus: List[int], include_cuda: bool = False, include_mps:
     Raises:
         MisconfigurationException:
             If machine has fewer available GPUs than requested.
+
     """
     if sum((include_cuda, include_mps)) == 0:
         raise ValueError("At least one gpu type should be specified!")
@@ -174,6 +173,7 @@ def _check_unique(device_ids: List[int]) -> None:
     Raises:
         MisconfigurationException:
             If ``device_ids`` of GPUs aren't unique
+
     """
     if len(device_ids) != len(set(device_ids)):
         raise MisconfigurationException("Device ID's (GPU) must be unique.")
@@ -193,7 +193,7 @@ def _check_data_type(device_ids: Any) -> None:
 
     if device_ids is None:
         return
-    elif isinstance(device_ids, (MutableSequence, tuple)):
+    if isinstance(device_ids, (MutableSequence, tuple)):
         for id_ in device_ids:
             if type(id_) is not int:
                 raise MisconfigurationException(f"{msg} a sequence of {type(id_).__name__}.")
