@@ -17,8 +17,8 @@ min_seed_value = np.iinfo(np.uint32).min
 
 
 def seed_everything(seed: Optional[int] = None, workers: bool = False) -> int:
-    """Function that sets seed for pseudo-random number generators in: pytorch, numpy, python.random In addition,
-    sets the following environment variables:
+    """Function that sets seed for pseudo-random number generators in: pytorch, numpy, python.random In addition, sets
+    the following environment variables:
 
     - `PL_GLOBAL_SEED`: will be passed to spawned subprocesses (e.g. ddp_spawn backend).
     - `PL_SEED_WORKERS`: (optional) is set to 1 if ``workers=True``.
@@ -31,6 +31,7 @@ def seed_everything(seed: Optional[int] = None, workers: bool = False) -> int:
             Trainer with a ``worker_init_fn``. If the user already provides such a function
             for their dataloaders, setting this argument will have no influence. See also:
             :func:`~lightning.fabric.utilities.seed.pl_worker_init_function`.
+
     """
     if seed is None:
         env_seed = os.environ.get("PL_GLOBAL_SEED")
@@ -63,13 +64,14 @@ def seed_everything(seed: Optional[int] = None, workers: bool = False) -> int:
 
 
 def _select_seed_randomly(min_seed_value: int = min_seed_value, max_seed_value: int = max_seed_value) -> int:
-    return random.randint(min_seed_value, max_seed_value)
+    return random.randint(min_seed_value, max_seed_value)  # noqa: S311
 
 
 def reset_seed() -> None:
     """Reset the seed to the value that :func:`lightning.fabric.utilities.seed.seed_everything` previously set.
 
     If :func:`lightning.fabric.utilities.seed.seed_everything` is unused, this function will do nothing.
+
     """
     seed = os.environ.get("PL_GLOBAL_SEED", None)
     if seed is None:
