@@ -16,6 +16,7 @@ from typing import Any, Dict, List
 import torch
 from lightning_utilities.core.imports import package_available
 
+from lightning.fabric.accelerators import _AcceleratorRegistry
 from lightning.fabric.utilities.types import _DEVICE
 from lightning.pytorch.accelerators.accelerator import Accelerator
 
@@ -34,6 +35,7 @@ class IPUAccelerator(Accelerator):
     """Accelerator for IPUs.
 
     .. warning::  Use of this accelerator beyond import and instantiation is experimental.
+
     """
 
     def setup_device(self, device: torch.device) -> None:
@@ -68,7 +70,7 @@ class IPUAccelerator(Accelerator):
         return _IPU_AVAILABLE
 
     @classmethod
-    def register_accelerators(cls, accelerator_registry: Dict) -> None:
+    def register_accelerators(cls, accelerator_registry: _AcceleratorRegistry) -> None:
         accelerator_registry.register(
             "ipu",
             cls,
