@@ -25,6 +25,7 @@ class TPUAccelerator(Accelerator):
     """Accelerator for TPU devices.
 
     .. warning::  Use of this accelerator beyond import and instantiation is experimental.
+
     """
 
     def __init__(self, *args: Any, **kwargs: Any) -> None:
@@ -43,17 +44,17 @@ class TPUAccelerator(Accelerator):
 
         Returns:
             A dictionary mapping the metrics (free memory and peak memory) to their values.
+
         """
         import torch_xla.core.xla_model as xm
 
         memory_info = xm.get_memory_info(device)
         free_memory = memory_info["kb_free"]
         peak_memory = memory_info["kb_total"] - free_memory
-        device_stats = {
+        return {
             "avg. free memory (MB)": free_memory,
             "avg. peak memory (MB)": peak_memory,
         }
-        return device_stats
 
     def teardown(self) -> None:
         pass
