@@ -11,10 +11,7 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-r"""
-Base class used to build new callbacks.
-
-"""
+r"""Base class used to build new callbacks."""
 
 from typing import Any, Dict, Optional, Type
 
@@ -26,10 +23,10 @@ from lightning.pytorch.utilities.types import STEP_OUTPUT
 
 
 class Callback:
-    r"""
-    Abstract base class used to build new callbacks.
+    r"""Abstract base class used to build new callbacks.
 
     Subclass this class and override any of the relevant hooks
+
     """
 
     @property
@@ -39,6 +36,7 @@ class Callback:
         Used to store and retrieve a callback's state from the checkpoint dictionary by
         ``checkpoint["callbacks"][state_key]``. Implementations of a callback need to provide a unique state key if 1)
         the callback has state and 2) it is desired to maintain the state of multiple instances of that callback.
+
         """
         return self.__class__.__qualname__
 
@@ -48,11 +46,12 @@ class Callback:
         return type(self)
 
     def _generate_state_key(self, **kwargs: Any) -> str:
-        """Formats a set of key-value pairs into a state key string with the callback class name prefixed. Useful
-        for defining a :attr:`state_key`.
+        """Formats a set of key-value pairs into a state key string with the callback class name prefixed. Useful for
+        defining a :attr:`state_key`.
 
         Args:
             **kwargs: A set of key-value pairs. Must be serializable to :class:`str`.
+
         """
         return f"{self.__class__.__qualname__}{repr(kwargs)}"
 
@@ -87,6 +86,7 @@ class Callback:
         Note:
             The value ``outputs["loss"]`` here will be the normalized value w.r.t ``accumulate_grad_batches`` of the
             loss returned from ``training_step``.
+
         """
 
     def on_train_epoch_start(self, trainer: "pl.Trainer", pl_module: "pl.LightningModule") -> None:
@@ -118,6 +118,7 @@ class Callback:
                     pl_module.log("training_epoch_mean", epoch_mean)
                     # free up the memory
                     pl_module.training_step_outputs.clear()
+
         """
 
     def on_validation_epoch_start(self, trainer: "pl.Trainer", pl_module: "pl.LightningModule") -> None:
@@ -247,25 +248,25 @@ class Callback:
     def on_save_checkpoint(
         self, trainer: "pl.Trainer", pl_module: "pl.LightningModule", checkpoint: Dict[str, Any]
     ) -> None:
-        r"""
-        Called when saving a checkpoint to give you a chance to store anything else you might want to save.
+        r"""Called when saving a checkpoint to give you a chance to store anything else you might want to save.
 
         Args:
             trainer: the current :class:`~lightning.pytorch.trainer.Trainer` instance.
             pl_module: the current :class:`~lightning.pytorch.core.module.LightningModule` instance.
             checkpoint: the checkpoint dictionary that will be saved.
+
         """
 
     def on_load_checkpoint(
         self, trainer: "pl.Trainer", pl_module: "pl.LightningModule", checkpoint: Dict[str, Any]
     ) -> None:
-        r"""
-        Called when loading a model checkpoint, use to reload state.
+        r"""Called when loading a model checkpoint, use to reload state.
 
         Args:
             trainer: the current :class:`~lightning.pytorch.trainer.Trainer` instance.
             pl_module: the current :class:`~lightning.pytorch.core.module.LightningModule` instance.
             checkpoint: the full checkpoint dictionary that got loaded by the Trainer.
+
         """
 
     def on_before_backward(self, trainer: "pl.Trainer", pl_module: "pl.LightningModule", loss: Tensor) -> None:
