@@ -11,9 +11,7 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-r"""
-Early Stopping
-^^^^^^^^^^^^^^
+r"""Early Stopping ^^^^^^^^^^^^^^
 
 Monitor a metric and stop training when it stops improving.
 
@@ -35,8 +33,7 @@ log = logging.getLogger(__name__)
 
 
 class EarlyStopping(Callback):
-    r"""
-    Monitor a metric and stop training when it stops improving.
+    r"""Monitor a metric and stop training when it stops improving.
 
     Args:
         monitor: quantity to be monitored.
@@ -85,6 +82,7 @@ class EarlyStopping(Callback):
         *monitor, mode*
 
         Read more: :ref:`Persisting Callback State <extensions/callbacks_state:save callback state>`
+
     """
     mode_dict = {"min": torch.lt, "max": torch.gt}
 
