@@ -11,11 +11,7 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-r"""
-Finetuning Callback
-^^^^^^^^^^^^^^^^^^^^
-Freeze and unfreeze models for finetuning purposes
-"""
+r"""Finetuning Callback ^^^^^^^^^^^^^^^^^^^^ Freeze and unfreeze models for finetuning purposes."""
 import logging
 from typing import Any, Callable, Dict, Generator, Iterable, List, Optional, Union
 
@@ -37,8 +33,7 @@ def multiplicative(epoch: int) -> float:
 
 
 class BaseFinetuning(Callback):
-    r"""
-    This class implements the base logic for writing your own Finetuning Callback.
+    r"""This class implements the base logic for writing your own Finetuning Callback.
 
     .. warning::  This is an :ref:`experimental <versioning:Experimental API>` feature.
 
@@ -79,6 +74,7 @@ class BaseFinetuning(Callback):
         ...                 optimizer=optimizer,
         ...                 train_bn=True,
         ...             )
+
     """
 
     def __init__(self) -> None:
@@ -92,7 +88,7 @@ class BaseFinetuning(Callback):
 
     def load_state_dict(self, state_dict: Dict[str, Any]) -> None:
         self._restarting = True
-        if "internal_optimizer_metadata" in state_dict:
+        if "internal_optimizer_metadata" in state_dict:  # noqa: SIM401
             self._internal_optimizer_metadata = state_dict["internal_optimizer_metadata"]
         else:
             # compatibility to load from old checkpoints before PR #11887
@@ -111,14 +107,15 @@ class BaseFinetuning(Callback):
 
     @staticmethod
     def flatten_modules(modules: Union[Module, Iterable[Union[Module, Iterable]]]) -> List[Module]:
-        """This function is used to flatten a module or an iterable of modules into a list of its leaf modules
-        (modules with no children) and parent modules that have parameters directly themselves.
+        """This function is used to flatten a module or an iterable of modules into a list of its leaf modules (modules
+        with no children) and parent modules that have parameters directly themselves.
 
         Args:
             modules: A given module or an iterable of modules
 
         Returns:
             List of modules
+
         """
         if isinstance(modules, ModuleDict):
             modules = modules.values()
@@ -147,6 +144,7 @@ class BaseFinetuning(Callback):
             requires_grad: Whether to create a generator for trainable or non-trainable parameters.
         Returns:
             Generator
+
         """
         modules = BaseFinetuning.flatten_modules(modules)
         for mod in modules:
@@ -163,6 +161,7 @@ class BaseFinetuning(Callback):
 
         Args:
             modules: A given module or an iterable of modules
+
         """
         modules = BaseFinetuning.flatten_modules(modules)
         for module in modules:
@@ -178,6 +177,7 @@ class BaseFinetuning(Callback):
 
         Args:
             module: A given module
+
         """
         if isinstance(module, _BatchNorm):
             module.track_running_stats = False
@@ -195,6 +195,7 @@ class BaseFinetuning(Callback):
 
         Returns:
             None
+
         """
         modules = BaseFinetuning.flatten_modules(modules)
         for mod in modules:
@@ -213,6 +214,7 @@ class BaseFinetuning(Callback):
 
         Returns:
             List of parameters not contained in this optimizer param groups
+
         """
         out_params = []
         removed_params = []
@@ -250,6 +252,7 @@ class BaseFinetuning(Callback):
             initial_denom_lr: If no lr is provided, the learning from the first param group will be used
                 and divided by `initial_denom_lr`.
             train_bn: Whether to train the BatchNormalization layers.
+
         """
         BaseFinetuning.make_trainable(modules)
         params_lr = optimizer.param_groups[0]["lr"] if lr is None else float(lr)
