@@ -33,7 +33,7 @@ import yaml
 from torch import Tensor
 
 import lightning.pytorch as pl
-from lightning.fabric.utilities.cloud_io import get_filesystem
+from lightning.fabric.utilities.cloud_io import _is_dir, get_filesystem
 from lightning.fabric.utilities.types import _PATH
 from lightning.pytorch.callbacks import Checkpoint
 from lightning.pytorch.utilities.exceptions import MisconfigurationException
@@ -456,7 +456,6 @@ class ModelCheckpoint(Checkpoint):
         every_n_epochs: Optional[int],
         train_time_interval: Optional[timedelta],
     ) -> None:
-
         # Default to running once after each validation epoch if neither
         # every_n_train_steps nor every_n_epochs is set
         if every_n_train_steps is None and every_n_epochs is None and train_time_interval is None:
@@ -508,19 +507,23 @@ class ModelCheckpoint(Checkpoint):
 
         # check and parse user passed keys in the string
         groups = re.findall(r"(\{.*?)[:\}]", filename)
-        if len(groups) >= 0:
-            for group in groups:
-                name = group[1:]
 
-                if auto_insert_metric_name:
-                    filename = filename.replace(group, name + "={" + name)
+        # sort keys from longest to shortest to avoid replacing substring
+        # eg: if keys are "epoch" and "epoch_test", the latter must be replaced first
+        groups = sorted(groups, key=lambda x: len(x), reverse=True)
 
-                # support for dots: https://stackoverflow.com/a/7934969
-                filename = filename.replace(group, f"{{0[{name}]")
+        for group in groups:
+            name = group[1:]
 
-                if name not in metrics:
-                    metrics[name] = torch.tensor(0)
-            filename = filename.format(metrics)
+            if auto_insert_metric_name:
+                filename = filename.replace(group, name + "={" + name)
+
+            # support for dots: https://stackoverflow.com/a/7934969
+            filename = filename.replace(group, f"{{0[{name}]")
+
+            if name not in metrics:
+                metrics[name] = torch.tensor(0)
+        filename = filename.format(metrics)
 
         if prefix:
             filename = cls.CHECKPOINT_JOIN_CHAR.join([prefix, filename])
@@ -557,6 +560,7 @@ class ModelCheckpoint(Checkpoint):
             >>> ckpt = ModelCheckpoint(filename='{step}')
             >>> os.path.basename(ckpt.format_checkpoint_name(dict(step=0)))
             'step=0.ckpt'
+
         """
         filename = filename or self.filename
         filename = self._format_checkpoint_name(filename, metrics, auto_insert_metric_name=self.auto_insert_metric_name)
@@ -576,6 +580,7 @@ class ModelCheckpoint(Checkpoint):
         3.  The ``Trainer``'s ``default_root_dir`` if the trainer has no loggers
 
         The path gets extended with subdirectory "checkpoints".
+
         """
         if self.dirpath is not None:
             # short circuit if dirpath was passed to ModelCheckpoint
@@ -608,7 +613,7 @@ class ModelCheckpoint(Checkpoint):
         return set()
 
     def __warn_if_dir_not_empty(self, dirpath: _PATH) -> None:
-        if self.save_top_k != 0 and self._fs.isdir(dirpath) and len(self._fs.ls(dirpath)) > 0:
+        if self.save_top_k != 0 and _is_dir(self._fs, dirpath, strict=True) and len(self._fs.ls(dirpath)) > 0:
             rank_zero_warn(f"Checkpoint directory {dirpath} exists and is not empty.")
 
     def _get_metric_interpolated_filepath_name(
