@@ -74,7 +74,7 @@ class LightningArgumentParser(ArgumentParser):
     def __init__(
         self,
         *args: Any,
-        description: str = "pytorch-lightning trainer command line tool",
+        description: str = "Lightning Trainer command line tool",
         env_prefix: str = "PL",
         default_env: bool = False,
         **kwargs: Any,
@@ -88,6 +88,7 @@ class LightningArgumentParser(ArgumentParser):
             description: Description of the tool shown when running ``--help``.
             env_prefix: Prefix for environment variables. Set ``default_env=True`` to enable env parsing.
             default_env: Whether to parse environment variables.
+
         """
         if not _JSONARGPARSE_SIGNATURES_AVAILABLE:
             raise ModuleNotFoundError(
@@ -122,6 +123,7 @@ class LightningArgumentParser(ArgumentParser):
 
         Returns:
             A list with the names of the class arguments added.
+
         """
         if callable(lightning_class) and not isinstance(lightning_class, type):
             lightning_class = class_from_function(lightning_class)
@@ -157,6 +159,7 @@ class LightningArgumentParser(ArgumentParser):
             optimizer_class: Any subclass of :class:`torch.optim.Optimizer`. Use tuple to allow subclasses.
             nested_key: Name of the nested namespace to store arguments.
             link_to: Dot notation of a parser key to set arguments or AUTOMATIC.
+
         """
         if isinstance(optimizer_class, tuple):
             assert all(issubclass(o, Optimizer) for o in optimizer_class)
@@ -182,6 +185,7 @@ class LightningArgumentParser(ArgumentParser):
                 tuple to allow subclasses.
             nested_key: Name of the nested namespace to store arguments.
             link_to: Dot notation of a parser key to set arguments or AUTOMATIC.
+
         """
         if isinstance(lr_scheduler_class, tuple):
             assert all(issubclass(o, LRSchedulerTypeTuple) for o in lr_scheduler_class)
@@ -207,6 +211,7 @@ class SaveConfigCallback(Callback):
 
     Raises:
         RuntimeError: If the config file already exists in the directory to avoid overwriting a previous run
+
     """
 
     def __init__(
@@ -280,8 +285,8 @@ class LightningCLI:
         run: bool = True,
         auto_configure_optimizers: bool = True,
     ) -> None:
-        """Receives as input pytorch-lightning classes (or callables which return pytorch-lightning classes), which
-        are called / instantiated using a parsed configuration file and / or command line args.
+        """Receives as input pytorch-lightning classes (or callables which return pytorch-lightning classes), which are
+        called / instantiated using a parsed configuration file and / or command line args.
 
         Parsing of configuration from environment variables can be enabled by setting ``parser_kwargs={"default_env":
         True}``. A full configuration yaml would be parsed from ``PL_CONFIG`` if set. Individual settings are so parsed
@@ -319,6 +324,7 @@ class LightningCLI:
                 ``dict`` or ``jsonargparse.Namespace``.
             run: Whether subcommands should be added to run a :class:`~lightning.pytorch.trainer.trainer.Trainer`
                 method. If set to ``False``, the trainer and model classes will be instantiated only.
+
         """
         self.save_config_callback = save_config_callback
         self.save_config_kwargs = save_config_kwargs or {}
@@ -424,6 +430,7 @@ class LightningCLI:
 
         Args:
             parser: The parser object to which arguments can be added
+
         """
 
     @staticmethod
@@ -507,6 +514,7 @@ class LightningCLI:
 
         Args:
             kwargs: Any custom trainer arguments.
+
         """
         extra_callbacks = [self._get(self.config_init, c) for c in self._parser(self.subcommand).callback_keys]
         trainer_config = {**self._get(self.config_init, "trainer", default={}), **kwargs}
@@ -665,7 +673,10 @@ class LightningCLI:
             config_seed = seed_everything(workers=True)
         else:
             config_seed = seed_everything(config_seed, workers=True)
-        self.config["seed_everything"] = config_seed
+        if self.subcommand:
+            self.config[self.subcommand]["seed_everything"] = config_seed
+        else:
+            self.config["seed_everything"] = config_seed
 
 
 def _class_path_from_class(class_type: Type) -> str:
@@ -696,6 +707,7 @@ def instantiate_class(args: Union[Any, Tuple[Any, ...]], init: Dict[str, Any]) -
 
     Returns:
         The instantiated class object.
+
     """
     kwargs = init.get("init_args", {})
     if not isinstance(args, tuple):
