@@ -67,7 +67,13 @@ from lightning.pytorch.utilities.exceptions import MisconfigurationException
 from lightning.pytorch.utilities.imports import _TORCHMETRICS_GREATER_EQUAL_0_9_1
 from lightning.pytorch.utilities.rank_zero import rank_zero_debug, rank_zero_warn, WarningCache
 from lightning.pytorch.utilities.signature_utils import is_param_in_hook_signature
-from lightning.pytorch.utilities.types import _METRIC, LRSchedulerPLType, LRSchedulerTypeUnion, STEP_OUTPUT
+from lightning.pytorch.utilities.types import (
+    _METRIC,
+    LRSchedulerPLType,
+    LRSchedulerTypeUnion,
+    OptimizerLRScheduler,
+    STEP_OUTPUT,
+)
 
 _ONNX_AVAILABLE = RequirementCache("onnx")
 
@@ -153,11 +159,14 @@ class LightningModule(
 
         Returns:
             A single optimizer, or a list of optimizers in case multiple ones are present.
+
         """
         if self._fabric:
             opts: MODULE_OPTIMIZERS = self._fabric_optimizers
         elif use_pl_optimizer:
             opts = self.trainer.strategy._lightning_optimizers
+            for opt in opts:
+                opt.refresh()
         else:
             opts = self.trainer.optimizers
 
@@ -172,12 +181,12 @@ class LightningModule(
         return opts
 
     def lr_schedulers(self) -> Union[None, List[LRSchedulerPLType], LRSchedulerPLType]:
-        """Returns the learning rate scheduler(s) that are being used during training. Useful for manual
-        optimization.
+        """Returns the learning rate scheduler(s) that are being used during training. Useful for manual optimization.
 
         Returns:
             A single scheduler, or a list of schedulers in case multiple ones are present, or ``None`` if no
             schedulers were returned in :meth:`configure_optimizers`.
+
         """
         if not self.trainer.lr_scheduler_configs:
             return None
@@ -205,9 +214,9 @@ class LightningModule(
         for v in self.children():
             if isinstance(v, LightningModule):
                 v.trainer = trainer  # type: ignore[assignment]
-        if not _TORCH_GREATER_EQUAL_2_0:  # https://github.com/pytorch/pytorch/issues/95857
-            if trainer is not None and not isinstance(trainer, weakref.ProxyTypes):
-                trainer = weakref.proxy(trainer)
+        # https://github.com/pytorch/pytorch/issues/95857
+        if not _TORCH_GREATER_EQUAL_2_0 and trainer is not None and not isinstance(trainer, weakref.ProxyTypes):
+            trainer = weakref.proxy(trainer)
         self._trainer = trainer
 
     @property
@@ -251,6 +260,7 @@ class LightningModule(
         """Total training batches seen across all epochs.
 
         If no Trainer is attached, this propery is 0.
+
         """
         return self.trainer.global_step if self._trainer else 0
 
@@ -293,7 +303,7 @@ class LightningModule(
         """Reference to the list of loggers in the Trainer."""
         if self._fabric is not None:
             return self._fabric.loggers
-        elif self._trainer is not None:
+        if self._trainer is not None:
             return self._trainer.loggers
         return []  # type: ignore[return-value]
 
@@ -309,9 +319,8 @@ class LightningModule(
                 trainer_method = call._call_lightning_datamodule_hook
 
             return trainer_method(trainer, hook_name, *args)
-        else:
-            hook = getattr(self, hook_name)
-            return hook(*args)
+        hook = getattr(self, hook_name)
+        return hook(*args)
 
     def _on_before_batch_transfer(self, batch: Any, dataloader_idx: int = 0) -> Any:
         return self._call_batch_hook("on_before_batch_transfer", batch, dataloader_idx)
@@ -325,8 +334,7 @@ class LightningModule(
         return batch
 
     def print(self, *args: Any, **kwargs: Any) -> None:
-        r"""
-        Prints only from process 0. Use this in any distributed mode to log only once.
+        r"""Prints only from process 0. Use this in any distributed mode to log only once.
 
         Args:
             *args: The thing to print. The same as for Python's built-in print function.
@@ -393,6 +401,7 @@ class LightningModule(
                 :class:`torchmetrics.Metric` in your model. This is found automatically if it is a model attribute.
             rank_zero_only: Whether the value will be logged only on rank 0. This will prevent synchronization which
                 would produce a deadlock as not all processes would perform this log call.
+
         """
         if self._fabric is not None:
             self._log_dict_through_fabric(dictionary={name: value}, logger=logger)
@@ -555,6 +564,7 @@ class LightningModule(
                 but some data structures might need to explicitly provide it.
             rank_zero_only: Whether the value will be logged only on rank 0. This will prevent synchronization which
                 would produce a deadlock as not all processes would perform this log call.
+
         """
         if self._fabric is not None:
             return self._log_dict_through_fabric(dictionary=dictionary, logger=logger)
@@ -582,6 +592,7 @@ class LightningModule(
                 batch_size=batch_size,
                 rank_zero_only=rank_zero_only,
             )
+        return None
 
     def _log_dict_through_fabric(self, dictionary: Mapping[str, Any], logger: Optional[bool] = None) -> None:
         if logger is False:
@@ -636,6 +647,7 @@ class LightningModule(
         Return:
             A tensor of shape (world_size, batch, ...), or if the input was a collection
             the output will also be a collection with tensors of this shape.
+
         """
         group = group if group is not None else torch.distributed.group.WORLD
         all_gather = self.trainer.strategy.all_gather
@@ -643,8 +655,7 @@ class LightningModule(
         return apply_to_collection(data, Tensor, all_gather, group=group, sync_grads=sync_grads)
 
     def forward(self, *args: Any, **kwargs: Any) -> Any:
-        r"""
-        Same as :meth:`torch.nn.Module.forward`.
+        r"""Same as :meth:`torch.nn.Module.forward`.
 
         Args:
             *args: Whatever you decide to pass into the forward method.
@@ -656,9 +667,8 @@ class LightningModule(
         return super().forward(*args, **kwargs)
 
     def training_step(self, *args: Any, **kwargs: Any) -> STEP_OUTPUT:  # type: ignore[return-value]
-        r"""
-        Here you compute and return the training loss and some additional metrics for e.g.
-        the progress bar or logger.
+        r"""Here you compute and return the training loss and some additional metrics for e.g. the progress bar or
+        logger.
 
         Args:
             batch (:class:`~torch.Tensor` | (:class:`~torch.Tensor`, ...) | [:class:`~torch.Tensor`, ...]):
@@ -707,13 +717,13 @@ class LightningModule(
         Note:
             When ``accumulate_grad_batches`` > 1, the loss returned here will be automatically
             normalized by ``accumulate_grad_batches`` internally.
+
         """
         rank_zero_warn("`training_step` must be implemented to be used with the Lightning Trainer")
 
     def validation_step(self, *args: Any, **kwargs: Any) -> Optional[STEP_OUTPUT]:
-        r"""
-        Operates on a single batch of data from the validation set.
-        In this step you'd might generate examples or calculate anything of interest like accuracy.
+        r"""Operates on a single batch of data from the validation set. In this step you'd might generate examples or
+        calculate anything of interest like accuracy.
 
         Args:
             batch: The output of your :class:`~torch.utils.data.DataLoader`.
@@ -776,13 +786,12 @@ class LightningModule(
             When the :meth:`validation_step` is called, the model has been put in eval mode
             and PyTorch gradients have been disabled. At the end of validation,
             the model goes back to training mode and gradients are enabled.
+
         """
 
     def test_step(self, *args: Any, **kwargs: Any) -> Optional[STEP_OUTPUT]:
-        r"""
-        Operates on a single batch of data from the test set.
-        In this step you'd normally generate examples or calculate anything of interest
-        such as accuracy.
+        r"""Operates on a single batch of data from the test set. In this step you'd normally generate examples or
+        calculate anything of interest such as accuracy.
 
         Args:
             batch: The output of your :class:`~torch.utils.data.DataLoader`.
@@ -847,6 +856,7 @@ class LightningModule(
             When the :meth:`test_step` is called, the model has been put in eval mode and
             PyTorch gradients have been disabled. At the end of the test epoch, the model goes back
             to training mode and gradients are enabled.
+
         """
 
     def predict_step(self, batch: Any, batch_idx: int, dataloader_idx: int = 0) -> Any:
@@ -906,11 +916,10 @@ class LightningModule(
         """
         return []
 
-    def configure_optimizers(self) -> Any:
-        r"""
-        Choose what optimizers and learning-rate schedulers to use in your optimization.
-        Normally you'd need one. But in the case of GANs or similar you might have multiple.
-        Optimization with multiple optimizers only works in the manual optimization mode.
+    def configure_optimizers(self) -> OptimizerLRScheduler:
+        r"""Choose what optimizers and learning-rate schedulers to use in your optimization. Normally you'd need one.
+        But in the case of GANs or similar you might have multiple. Optimization with multiple optimizers only works in
+        the manual optimization mode.
 
         Return:
             Any of these 6 options.
@@ -1005,6 +1014,7 @@ class LightningModule(
             - If you use multiple optimizers, you will have to switch to 'manual optimization' mode and step them
               yourself.
             - If you need to control how often the optimizer steps, override the :meth:`optimizer_step` hook.
+
         """
         rank_zero_warn("`configure_optimizers` must be implemented to be used with the Lightning Trainer")
 
@@ -1054,13 +1064,14 @@ class LightningModule(
             loss.backward(*args, **kwargs)
 
     def toggle_optimizer(self, optimizer: Union[Optimizer, LightningOptimizer]) -> None:
-        """Makes sure only the gradients of the current optimizer's parameters are calculated in the training step
-        to prevent dangling gradients in multiple-optimizer setup.
+        """Makes sure only the gradients of the current optimizer's parameters are calculated in the training step to
+        prevent dangling gradients in multiple-optimizer setup.
 
         It works with :meth:`untoggle_optimizer` to make sure ``param_requires_grad_state`` is properly reset.
 
         Args:
             optimizer: The optimizer to toggle.
+
         """
         # Iterate over all optimizer parameters to preserve their `requires_grad` information
         # in case these are pre-defined during `configure_optimizers`
@@ -1117,6 +1128,7 @@ class LightningModule(
             gradient_clip_val: The value at which to clip gradients.
             gradient_clip_algorithm: The gradient clipping algorithm to use. Pass ``gradient_clip_algorithm="value"``
                 to clip by value, and ``gradient_clip_algorithm="norm"`` to clip by norm.
+
         """
 
         if self.fabric is not None:
@@ -1230,9 +1242,8 @@ class LightningModule(
         optimizer: Union[Optimizer, LightningOptimizer],
         optimizer_closure: Optional[Callable[[], Any]] = None,
     ) -> None:
-        r"""
-        Override this method to adjust the default way the :class:`~lightning.pytorch.trainer.trainer.Trainer` calls
-        the optimizer.
+        r"""Override this method to adjust the default way the :class:`~lightning.pytorch.trainer.trainer.Trainer`
+        calls the optimizer.
 
         By default, Lightning calls ``step()`` and ``zero_grad()`` as shown in the example.
         This method (and ``zero_grad()``) won't be called during the accumulation phase when
@@ -1287,8 +1298,7 @@ class LightningModule(
         optimizer.zero_grad()
 
     def freeze(self) -> None:
-        r"""
-        Freeze all params for inference.
+        r"""Freeze all params for inference.
 
         Example::
 
@@ -1308,6 +1318,7 @@ class LightningModule(
 
             model = MyLightningModule(...)
             model.unfreeze()
+
         """
         for param in self.parameters():
             param.requires_grad = True
@@ -1330,7 +1341,8 @@ class LightningModule(
             input_sample: An input for tracing. Default: None (Use self.example_input_array)
             **kwargs: Will be passed to torch.onnx.export function.
 
-        Example:
+        Example::
+
             class SimpleModel(LightningModule):
                 def __init__(self):
                     super().__init__()
@@ -1342,6 +1354,7 @@ class LightningModule(
             model = SimpleModel()
             input_sample = torch.randn(1, 64)
             model.to_onnx("export.onnx", input_sample, export_params=True)
+
         """
         if _TORCH_GREATER_EQUAL_2_0 and not _ONNX_AVAILABLE:
             raise ModuleNotFoundError(
@@ -1394,23 +1407,22 @@ class LightningModule(
               to use this feature without limitations. See also the :mod:`torch.jit`
               documentation for supported features.
 
-        Example:
-            >>> class SimpleModel(LightningModule):
-            ...     def __init__(self):
-            ...         super().__init__()
-            ...         self.l1 = torch.nn.Linear(in_features=64, out_features=4)
-            ...
-            ...     def forward(self, x):
-            ...         return torch.relu(self.l1(x.view(x.size(0), -1)))
-            ...
-            >>> import os
-            >>> model = SimpleModel()
-            >>> model.to_torchscript(file_path="model.pt")  # doctest: +SKIP
-            >>> os.path.isfile("model.pt")  # doctest: +SKIP
-            >>> torch.jit.save(model.to_torchscript(file_path="model_trace.pt", method='trace', # doctest: +SKIP
-            ...                                     example_inputs=torch.randn(1, 64)))  # doctest: +SKIP
-            >>> os.path.isfile("model_trace.pt")  # doctest: +SKIP
-            True
+        Example::
+
+            class SimpleModel(LightningModule):
+                def __init__(self):
+                    super().__init__()
+                    self.l1 = torch.nn.Linear(in_features=64, out_features=4)
+
+                def forward(self, x):
+                    return torch.relu(self.l1(x.view(x.size(0), -1)))
+
+            model = SimpleModel()
+            model.to_torchscript(file_path="model.pt")
+
+            torch.jit.save(model.to_torchscript(
+                file_path="model_trace.pt", method='trace', example_inputs=torch.randn(1, 64))
+            )
 
         Return:
             This LightningModule as a torchscript, regardless of whether `file_path` is
@@ -1547,6 +1559,7 @@ class LightningModule(
         """Adds ShardedTensor state dict hooks if ShardedTensors are supported.
 
         These hooks ensure that ShardedTensors are included when saving, and are loaded the LightningModule correctly.
+
         """
         if _TORCH_GREATER_EQUAL_2_1:
             # ShardedTensor is deprecated in favor of DistributedTensor
