@@ -41,9 +41,9 @@ if _COMET_AVAILABLE:
 
     try:
         from comet_ml.api import API
-    except ModuleNotFoundError:  # pragma: no-cover
+    except ModuleNotFoundError:
         # For more information, see: https://www.comet.ml/docs/python-sdk/releases/#release-300
-        from comet_ml.papi import API  # pragma: no-cover
+        from comet_ml.papi import API
 else:
     # needed for test mocks, these tests shall be updated
     comet_ml = None
@@ -52,9 +52,8 @@ else:
 
 
 class CometLogger(Logger):
-    r"""
-    Track your parameters, metrics, source code and more using
-    `Comet <https://www.comet.com/?utm_source=lightning.pytorch&utm_medium=referral>`_.
+    r"""Track your parameters, metrics, source code and more using `Comet
+    <https://www.comet.com/?utm_source=lightning.pytorch&utm_medium=referral>`_.
 
     Install it with pip:
 
@@ -205,6 +204,7 @@ class CometLogger(Logger):
             If required Comet package is not installed on the device.
         MisconfigurationException:
             If neither ``api_key`` nor ``save_dir`` are passed as arguments.
+
     """
 
     LOGGER_JOIN_CHAR = "-"
@@ -313,7 +313,7 @@ class CometLogger(Logger):
         return self._experiment
 
     @rank_zero_only
-    def log_hyperparams(self, params: Union[Dict[str, Any], Namespace]) -> None:
+    def log_hyperparams(self, params: Union[Dict[str, Any], Namespace]) -> None:  # type: ignore[override]
         params = _convert_params(params)
         params = _flatten_dict(params)
         self.experiment.log_parameters(params)
@@ -358,6 +358,7 @@ class CometLogger(Logger):
 
         Returns:
             The path to the save directory.
+
         """
         return self._save_dir
 
@@ -367,6 +368,7 @@ class CometLogger(Logger):
 
         Returns:
             The project name if it is specified, else "comet-default".
+
         """
         # Don't create an experiment if we don't have one
         if self._experiment is not None and self._experiment.project_name is not None:
@@ -390,6 +392,7 @@ class CometLogger(Logger):
             4. future experiment key.
 
             If none are present generates a new guid.
+
         """
         # Don't create an experiment if we don't have one
         if self._experiment is not None:
