@@ -25,7 +25,7 @@ from time import time
 from typing import Any, Dict, List, Literal, Mapping, Optional, Union
 
 import yaml
-from lightning_utilities.core.imports import RequirementCache
+from lightning_utilities.core.imports import module_available, RequirementCache
 from torch import Tensor
 
 from lightning.fabric.utilities.logger import _add_prefix, _convert_params, _flatten_dict
@@ -36,14 +36,15 @@ from lightning.pytorch.utilities.rank_zero import rank_zero_only, rank_zero_warn
 
 log = logging.getLogger(__name__)
 LOCAL_FILE_URI_PREFIX = "file:"
-_MLFLOW_FULL_AVAILABLE = RequirementCache("mlflow>=1.0.0")
-_MLFLOW_SKINNY_AVAILABLE = RequirementCache("mlflow-skinny>=1.0.0")
-_MLFLOW_AVAILABLE = _MLFLOW_FULL_AVAILABLE or _MLFLOW_SKINNY_AVAILABLE
+_MLFLOW_AVAILABLE = RequirementCache("mlflow>=1.0.0") or module_available("mlflow")
+
 if _MLFLOW_AVAILABLE:
+    import mlflow
     from mlflow.entities import Metric, Param
     from mlflow.tracking import context, MlflowClient
     from mlflow.utils.mlflow_tags import MLFLOW_RUN_NAME
 else:
+    mlflow = None
     MlflowClient, context = None, None
     Metric, Param = None, None
     MLFLOW_RUN_NAME = "mlflow.runName"
@@ -113,7 +114,7 @@ class MLFlowLogger(Logger):
             back to `file:<save_dir>`.
         tags: A dictionary tags for the experiment.
         save_dir: A path to a local directory where the MLflow runs get saved.
-            Defaults to `./mlflow` if `tracking_uri` is not provided.
+            Defaults to `./mlruns` if `tracking_uri` is not provided.
             Has no effect if `tracking_uri` is provided.
         log_model: Log checkpoints created by :class:`~lightning.pytorch.callbacks.model_checkpoint.ModelCheckpoint`
             as MLFlow artifacts.
@@ -132,6 +133,7 @@ class MLFlowLogger(Logger):
     Raises:
         ModuleNotFoundError:
             If required MLFlow package is not installed on the device.
+
     """
 
     LOGGER_JOIN_CHAR = "-"
@@ -149,9 +151,7 @@ class MLFlowLogger(Logger):
         run_id: Optional[str] = None,
     ):
         if not _MLFLOW_AVAILABLE:
-            raise ModuleNotFoundError(
-                f"{_MLFLOW_FULL_AVAILABLE!s}. You can also try {_MLFLOW_SKINNY_AVAILABLE.requirement!r}"
-            )
+            raise ModuleNotFoundError(str(_MLFLOW_AVAILABLE))
         super().__init__()
         if not tracking_uri:
             tracking_uri = f"{LOCAL_FILE_URI_PREFIX}{save_dir}"
@@ -184,10 +184,11 @@ class MLFlowLogger(Logger):
             self.logger.experiment.some_mlflow_function()
 
         """
-
         if self._initialized:
             return self._mlflow_client
 
+        mlflow.set_tracking_uri(self._tracking_uri)
+
         if self._run_id is not None:
             run = self._mlflow_client.get_run(self._run_id)
             self._experiment_id = run.info.experiment_id
@@ -223,6 +224,7 @@ class MLFlowLogger(Logger):
 
         Returns:
             The run id.
+
         """
         _ = self.experiment
         return self._run_id
@@ -233,12 +235,13 @@ class MLFlowLogger(Logger):
 
         Returns:
             The experiment id.
+
         """
         _ = self.experiment
         return self._experiment_id
 
     @rank_zero_only
-    def log_hyperparams(self, params: Union[Dict[str, Any], Namespace]) -> None:
+    def log_hyperparams(self, params: Union[Dict[str, Any], Namespace]) -> None:  # type: ignore[override]
         params = _convert_params(params)
         params = _flatten_dict(params)
 
@@ -300,9 +303,11 @@ class MLFlowLogger(Logger):
         Return:
             Local path to the root experiment directory if the tracking uri is local.
             Otherwise returns `None`.
+
         """
         if self._tracking_uri.startswith(LOCAL_FILE_URI_PREFIX):
             return self._tracking_uri.lstrip(LOCAL_FILE_URI_PREFIX)
+        return None
 
     @property
     def name(self) -> Optional[str]:
@@ -310,6 +315,7 @@ class MLFlowLogger(Logger):
 
         Returns:
             The experiment id.
+
         """
         return self.experiment_id
 
@@ -319,6 +325,7 @@ class MLFlowLogger(Logger):
 
         Returns:
             The run id.
+
         """
         return self.run_id
 
