@@ -19,6 +19,7 @@ __all__ = [
     "NeptuneLogger",
 ]
 
+import contextlib
 import logging
 import os
 from argparse import Namespace
@@ -34,13 +35,27 @@ from lightning.pytorch.loggers.logger import Logger, rank_zero_experiment
 from lightning.pytorch.utilities.model_summary import ModelSummary
 from lightning.pytorch.utilities.rank_zero import rank_zero_only
 
-_NEPTUNE_AVAILABLE = RequirementCache("neptune-client")
+# neptune is available with two names on PyPI : `neptune` and `neptune-client`
+_NEPTUNE_AVAILABLE = RequirementCache("neptune>=1.0")
+_NEPTUNE_CLIENT_AVAILABLE = RequirementCache("neptune-client")
+
 if _NEPTUNE_AVAILABLE:
-    from neptune import new as neptune
-    from neptune.new.run import Run
+    # >1.0 package structure
+    import neptune
+    from neptune import Run
+    from neptune.handler import Handler
+    from neptune.types import File
+    from neptune.utils import stringify_unsupported
+elif _NEPTUNE_CLIENT_AVAILABLE:
+    # <1.0 package structure
+    import neptune.new as neptune
+    from neptune.new import Run
+    from neptune.new.handler import Handler
+    from neptune.new.types import File
+    from neptune.new.utils import stringify_unsupported
 else:
-    # needed for test mocks, and function signatures
-    neptune, Run = None, None
+    # needed for tests, mocks and function signatures
+    neptune, Run, Handler, File, stringify_unsupported = None, None, None, None, None
 
 log = logging.getLogger(__name__)
 
@@ -48,14 +63,13 @@ _INTEGRATION_VERSION_KEY = "source_code/integrations/pytorch-lightning"
 
 
 class NeptuneLogger(Logger):
-    r"""
-    Log using `Neptune <https://neptune.ai>`_.
+    r"""Log using `Neptune <https://neptune.ai>`_.
 
     Install it with pip:
 
     .. code-block:: bash
 
-        pip install neptune-client
+        pip install neptune
 
     or conda:
 
@@ -65,17 +79,18 @@ class NeptuneLogger(Logger):
 
     **Quickstart**
 
-    Pass NeptuneLogger instance to the Trainer to log metadata with Neptune:
+    Pass a NeptuneLogger instance to the Trainer to log metadata with Neptune:
 
     .. code-block:: python
 
 
         from lightning.pytorch import Trainer
         from lightning.pytorch.loggers import NeptuneLogger
+        import neptune
 
         neptune_logger = NeptuneLogger(
-            api_key="ANONYMOUS",  # replace with your own
-            project="common/pytorch-lightning-integration",  # format "<WORKSPACE/PROJECT>"
+            api_key=neptune.ANONYMOUS_API_TOKEN,  # replace with your own
+            project="common/pytorch-lightning-integration",  # format "workspace-name/project-name"
             tags=["training", "resnet"],  # optional
         )
         trainer = Trainer(max_epochs=10, logger=neptune_logger)
@@ -86,7 +101,7 @@ class NeptuneLogger(Logger):
 
     .. code-block:: python
 
-        from neptune.new.types import File
+        from neptune.types import File
         from lightning.pytorch import LightningModule
 
 
@@ -94,24 +109,23 @@ class NeptuneLogger(Logger):
             def training_step(self, batch, batch_idx):
                 # log metrics
                 acc = ...
-                self.log("train/loss", loss)
+                self.append("train/loss", loss)
 
             def any_lightning_module_function_or_hook(self):
                 # log images
                 img = ...
-                self.logger.experiment["train/misclassified_images"].log(File.as_image(img))
+                self.logger.experiment["train/misclassified_images"].append(File.as_image(img))
 
                 # generic recipe
                 metadata = ...
-                self.logger.experiment["your/metadata/structure"].log(metadata)
+                self.logger.experiment["your/metadata/structure"] = metadata
 
-    Note that syntax: ``self.logger.experiment["your/metadata/structure"].log(metadata)`` is specific to Neptune
-    and it extends logger capabilities. Specifically, it allows you to log various types of metadata
-    like scores, files, images, interactive visuals, CSVs, etc.
-    Refer to the `Neptune docs <https://docs.neptune.ai/you-should-know/logging-metadata#essential-logging-methods>`_
-    for more detailed explanations.
-    You can also use regular logger methods ``log_metrics()``, and ``log_hyperparams()`` with NeptuneLogger
-    as these are also supported.
+    Note that the syntax ``self.logger.experiment["your/metadata/structure"].append(metadata)`` is specific to
+    Neptune and extends the logger capabilities. It lets you log various types of metadata, such as
+    scores, files, images, interactive visuals, and CSVs.
+    Refer to the `Neptune docs <https://docs.neptune.ai/logging/methods>`_
+    for details.
+    You can also use the regular logger methods ``log_metrics()``, and ``log_hyperparams()`` with NeptuneLogger.
 
     **Log after fitting or testing is finished**
 
@@ -133,22 +147,22 @@ class NeptuneLogger(Logger):
 
         # generic recipe
         metadata = ...
-        neptune_logger.experiment["your/metadata/structure"].log(metadata)
+        neptune_logger.experiment["your/metadata/structure"] = metadata
 
     **Log model checkpoints**
 
     If you have :class:`~lightning.pytorch.callbacks.ModelCheckpoint` configured,
-    Neptune logger automatically logs model checkpoints.
-    Model weights will be uploaded to the: "model/checkpoints" namespace in the Neptune Run.
-    You can disable this option:
+    the Neptune logger automatically logs model checkpoints.
+    Model weights will be uploaded to the "model/checkpoints" namespace in the Neptune run.
+    You can disable this option with:
 
     .. code-block:: python
 
-        neptune_logger = NeptuneLogger(project="common/pytorch-lightning-integration", log_model_checkpoints=False)
+        neptune_logger = NeptuneLogger(log_model_checkpoints=False)
 
     **Pass additional parameters to the Neptune run**
 
-    You can also pass ``neptune_run_kwargs`` to specify the run in the greater detail, like ``tags`` or ``description``:
+    You can also pass ``neptune_run_kwargs`` to add details to the run, like ``tags`` or ``description``:
 
     .. testcode::
         :skipif: not _NEPTUNE_AVAILABLE
@@ -164,7 +178,7 @@ class NeptuneLogger(Logger):
         )
         trainer = Trainer(max_epochs=3, logger=neptune_logger)
 
-    Check `run documentation <https://docs.neptune.ai/essentials/api-reference/run>`_
+    Check `run documentation <https://docs.neptune.ai/api/neptune/#init_run>`_
     for more info about additional run parameters.
 
     **Details about Neptune run structure**
@@ -172,45 +186,44 @@ class NeptuneLogger(Logger):
     Runs can be viewed as nested dictionary-like structures that you can define in your code.
     Thanks to this you can easily organize your metadata in a way that is most convenient for you.
 
-    The hierarchical structure that you apply to your metadata will be reflected later in the UI.
+    The hierarchical structure that you apply to your metadata is reflected in the Neptune web app.
 
-    You can organize this way any type of metadata - images, parameters, metrics, model checkpoint, CSV files, etc.
-
-    See Also:
+    See also:
         - Read about
-          `what object you can log to Neptune <https://docs.neptune.ai/you-should-know/what-can-you-log-and-display>`_.
-        - Check `example run <https://app.neptune.ai/o/common/org/pytorch-lightning-integration/e/PTL-1/all>`_
+          `what objects you can log to Neptune <https://docs.neptune.ai/logging/what_you_can_log/>`_.
+        - Check out an `example run <https://app.neptune.ai/o/common/org/pytorch-lightning-integration/e/PTL-1/all>`_
           with multiple types of metadata logged.
-        - For more detailed info check
-          `user guide <https://docs.neptune.ai/integrations-and-supported-tools/model-training/pytorch-lightning>`_.
+        - For more detailed examples, see the
+          `user guide <https://docs.neptune.ai/integrations/lightning/>`_.
 
     Args:
         api_key: Optional.
             Neptune API token, found on https://neptune.ai upon registration.
-            Read: `how to find and set Neptune API token <https://docs.neptune.ai/administration/security-and-privacy/
-            how-to-find-and-set-neptune-api-token>`_.
-            It is recommended to keep it in the `NEPTUNE_API_TOKEN`
-            environment variable and then you can drop ``api_key=None``.
+            You should save your token to the `NEPTUNE_API_TOKEN`
+            environment variable and leave the api_key argument out of your code.
+            Instructions: `Setting your API token <https://docs.neptune.ai/setup/setting_api_token/>`_.
         project: Optional.
-            Name of a project in a form of "my_workspace/my_project" for example "tom/mask-rcnn".
-            If ``None``, the value of `NEPTUNE_PROJECT` environment variable will be taken.
-            You need to create the project in https://neptune.ai first.
+            Name of a project in the form "workspace-name/project-name", for example "tom/mask-rcnn".
+            If ``None``, the value of `NEPTUNE_PROJECT` environment variable is used.
+            You need to create the project on https://neptune.ai first.
         name: Optional. Editable name of the run.
-            Run name appears in the "all metadata/sys" section in Neptune UI.
-        run: Optional. Default is ``None``. The Neptune ``Run`` object.
-            If specified, this `Run`` will be used for logging, instead of a new Run.
-            When run object is passed you can't specify other neptune properties.
+            The run name is displayed in the Neptune web app.
+        run: Optional. Default is ``None``. A Neptune ``Run`` object.
+            If specified, this existing run will be used for logging, instead of a new run being created.
+            You can also pass a namespace handler object; for example, ``run["test"]``, in which case all
+            metadata is logged under the "test" namespace inside the run.
         log_model_checkpoints: Optional. Default is ``True``. Log model checkpoint to Neptune.
             Works only if ``ModelCheckpoint`` is passed to the ``Trainer``.
         prefix: Optional. Default is ``"training"``. Root namespace for all metadata logging.
         \**neptune_run_kwargs: Additional arguments like ``tags``, ``description``, ``capture_stdout``, etc.
-            used when run is created.
+            used when a run is created.
 
     Raises:
         ModuleNotFoundError:
-            If required Neptune package is not installed.
+            If the required Neptune package is not installed.
         ValueError:
-            If argument passed to the logger's constructor is incorrect.
+            If an argument passed to the logger's constructor is incorrect.
+
     """
 
     LOGGER_JOIN_CHAR = "/"
@@ -223,12 +236,12 @@ class NeptuneLogger(Logger):
         api_key: Optional[str] = None,
         project: Optional[str] = None,
         name: Optional[str] = None,
-        run: Optional["Run"] = None,
+        run: Optional[Union["Run", "Handler"]] = None,
         log_model_checkpoints: Optional[bool] = True,
         prefix: str = "training",
         **neptune_run_kwargs: Any,
     ):
-        if not _NEPTUNE_AVAILABLE:
+        if not _NEPTUNE_AVAILABLE and not _NEPTUNE_CLIENT_AVAILABLE:
             raise ModuleNotFoundError(str(_NEPTUNE_AVAILABLE))
         # verify if user passed proper init arguments
         self._verify_input_arguments(api_key, project, name, run, neptune_run_kwargs)
@@ -246,15 +259,23 @@ class NeptuneLogger(Logger):
             self._retrieve_run_data()
 
             # make sure that we've log integration version for outside `Run` instances
-            self._run_instance[_INTEGRATION_VERSION_KEY] = pl.__version__
+            root_obj = self._run_instance
+            if isinstance(root_obj, Handler):
+                root_obj = root_obj.get_root_object()
+
+            root_obj[_INTEGRATION_VERSION_KEY] = pl.__version__
 
     def _retrieve_run_data(self) -> None:
         assert self._run_instance is not None
-        self._run_instance.wait()
+        root_obj = self._run_instance
+        if isinstance(root_obj, Handler):
+            root_obj = root_obj.get_root_object()
 
-        if self._run_instance.exists("sys/id"):
-            self._run_short_id = self._run_instance["sys/id"].fetch()
-            self._run_name = self._run_instance["sys/name"].fetch()
+        root_obj.wait()
+
+        if root_obj.exists("sys/id"):
+            self._run_short_id = root_obj["sys/id"].fetch()
+            self._run_name = root_obj["sys/name"].fetch()
         else:
             self._run_short_id = "OFFLINE"
             self._run_name = "offline-name"
@@ -263,10 +284,8 @@ class NeptuneLogger(Logger):
     def _neptune_init_args(self) -> Dict:
         args: Dict = {}
         # Backward compatibility in case of previous version retrieval
-        try:
+        with contextlib.suppress(AttributeError):
             args = self._neptune_run_kwargs
-        except AttributeError:
-            pass
 
         if self._project_name is not None:
             args["project"] = self._project_name
@@ -278,11 +297,9 @@ class NeptuneLogger(Logger):
             args["run"] = self._run_short_id
 
         # Backward compatibility in case of previous version retrieval
-        try:
+        with contextlib.suppress(AttributeError):
             if self._run_name is not None:
                 args["name"] = self._run_name
-        except AttributeError:
-            pass
 
         return args
 
@@ -297,12 +314,13 @@ class NeptuneLogger(Logger):
         api_key: Optional[str],
         project: Optional[str],
         name: Optional[str],
-        run: Optional["Run"],
+        run: Optional[Union["Run", "Handler"]],
         neptune_run_kwargs: dict,
     ) -> None:
-        # check if user passed the client `Run` object
-        if run is not None and not isinstance(run, Run):
-            raise ValueError("Run parameter expected to be of type `neptune.new.Run`.")
+        # check if user passed the client `Run`/`Handler` object
+        if run is not None and not isinstance(run, (Run, Handler)):
+            raise ValueError("Run parameter expected to be of type `neptune.Run`, or `neptune.handler.Handler`.")
+
         # check if user passed redundant neptune.init_run arguments when passed run
         any_neptune_init_arg_passed = any(arg is not None for arg in [api_key, project, name]) or neptune_run_kwargs
         if run is not None and any_neptune_init_arg_passed:
@@ -334,20 +352,20 @@ class NeptuneLogger(Logger):
                 def training_step(self, batch, batch_idx):
                     # log metrics
                     acc = ...
-                    self.logger.experiment["train/acc"].log(acc)
+                    self.logger.experiment["train/acc"].append(acc)
 
                     # log images
                     img = ...
-                    self.logger.experiment["train/misclassified_images"].log(File.as_image(img))
+                    self.logger.experiment["train/misclassified_images"].append(File.as_image(img))
 
-        Note that syntax: ``self.logger.experiment["your/metadata/structure"].log(metadata)``
-        is specific to Neptune and it extends logger capabilities.
-        Specifically, it allows you to log various types of metadata like scores, files,
-        images, interactive visuals, CSVs, etc. Refer to the
-        `Neptune docs <https://docs.neptune.ai/you-should-know/logging-metadata#essential-logging-methods>`_
+        Note that the syntax ``self.logger.experiment["your/metadata/structure"].append(metadata)``
+        is specific to Neptune and extends the logger capabilities.
+        It lets you log various types of metadata, such as scores, files,
+        images, interactive visuals, and CSVs. Refer to the
+        `Neptune docs <https://docs.neptune.ai/logging/methods>`_
         for more detailed explanations.
-        You can also use regular logger methods ``log_metrics()``, and ``log_hyperparams()``
-        with NeptuneLogger as these are also supported.
+        You can also use the regular logger methods ``log_metrics()``, and ``log_hyperparams()``
+        with NeptuneLogger.
         """
         return self.run
 
@@ -363,11 +381,10 @@ class NeptuneLogger(Logger):
         return self._run_instance
 
     @rank_zero_only
-    def log_hyperparams(self, params: Union[Dict[str, Any], Namespace]) -> None:  # skipcq: PYL-W0221
-        r"""
-        Log hyper-parameters to the run.
+    def log_hyperparams(self, params: Union[Dict[str, Any], Namespace]) -> None:  # type: ignore[override]
+        r"""Log hyperparameters to the run.
 
-        Hyperparams will be logged under the "<prefix>/hyperparams" namespace.
+        Hyperparameters will be logged under the "<prefix>/hyperparams" namespace.
 
         Note:
 
@@ -383,19 +400,21 @@ class NeptuneLogger(Logger):
         Example::
 
             from lightning.pytorch.loggers import NeptuneLogger
+            import neptune
 
             PARAMS = {
                 "batch_size": 64,
                 "lr": 0.07,
-                "decay_factor": 0.97
+                "decay_factor": 0.97,
             }
 
             neptune_logger = NeptuneLogger(
-                api_key="ANONYMOUS",
+                api_key=neptune.ANONYMOUS_API_TOKEN,
                 project="common/pytorch-lightning-integration"
             )
 
             neptune_logger.log_hyperparams(PARAMS)
+
         """
         params = _convert_params(params)
         params = _sanitize_callable_params(params)
@@ -403,15 +422,18 @@ class NeptuneLogger(Logger):
         parameters_key = self.PARAMETERS_KEY
         parameters_key = self._construct_path_with_prefix(parameters_key)
 
-        self.run[parameters_key] = params
+        self.run[parameters_key] = stringify_unsupported(params)
 
     @rank_zero_only
-    def log_metrics(self, metrics: Dict[str, Union[Tensor, float]], step: Optional[int] = None) -> None:
+    def log_metrics(  # type: ignore[override]
+        self, metrics: Dict[str, Union[Tensor, float]], step: Optional[int] = None
+    ) -> None:
         """Log metrics (numeric values) in Neptune runs.
 
         Args:
             metrics: Dictionary with metric names as keys and measured quantities as values.
             step: Step number at which the metrics should be recorded, currently ignored.
+
         """
         if rank_zero_only.rank != 0:
             raise ValueError("run tried to log from global_rank != 0")
@@ -421,7 +443,7 @@ class NeptuneLogger(Logger):
         for key, val in metrics.items():
             # `step` is ignored because Neptune expects strictly increasing step values which
             # Lightning does not always guarantee.
-            self.run[key].log(val)
+            self.run[key].append(val)
 
     @rank_zero_only
     def finalize(self, status: str) -> None:
@@ -457,6 +479,7 @@ class NeptuneLogger(Logger):
 
         Args:
             checkpoint_callback: the model checkpoint callback instance
+
         """
         if not self._log_model_checkpoints:
             return
@@ -468,11 +491,12 @@ class NeptuneLogger(Logger):
         if hasattr(checkpoint_callback, "last_model_path") and checkpoint_callback.last_model_path:
             model_last_name = self._get_full_model_name(checkpoint_callback.last_model_path, checkpoint_callback)
             file_names.add(model_last_name)
-            self.run[f"{checkpoints_namespace}/{model_last_name}"].upload(checkpoint_callback.last_model_path)
+            with open(checkpoint_callback.last_model_path, "rb") as fp:
+                self.run[f"{checkpoints_namespace}/{model_last_name}"] = File.from_stream(fp)
 
         # save best k models
         if hasattr(checkpoint_callback, "best_k_models"):
-            for key in checkpoint_callback.best_k_models.keys():
+            for key in checkpoint_callback.best_k_models:
                 model_name = self._get_full_model_name(key, checkpoint_callback)
                 file_names.add(model_name)
                 self.run[f"{checkpoints_namespace}/{model_name}"].upload(key)
@@ -483,7 +507,8 @@ class NeptuneLogger(Logger):
 
             model_name = self._get_full_model_name(checkpoint_callback.best_model_path, checkpoint_callback)
             file_names.add(model_name)
-            self.run[f"{checkpoints_namespace}/{model_name}"].upload(checkpoint_callback.best_model_path)
+            with open(checkpoint_callback.best_model_path, "rb") as fp:
+                self.run[f"{checkpoints_namespace}/{model_name}"] = File.from_stream(fp)
 
         # remove old models logged to experiment if they are not part of best k models at this point
         if self.run.exists(checkpoints_namespace):
@@ -508,10 +533,8 @@ class NeptuneLogger(Logger):
                 raise ValueError(f"{model_path} was expected to start with {expected_model_path}.")
             # Remove extension from filepath
             filepath, _ = os.path.splitext(model_path[len(expected_model_path) :])
-        else:
-            filepath = model_path
-
-        return filepath
+            return filepath
+        return model_path
 
     @classmethod
     def _get_full_model_names_from_exp_structure(cls, exp_structure: Dict[str, Any], namespace: str) -> Set[str]:
@@ -541,5 +564,6 @@ class NeptuneLogger(Logger):
         """Return the experiment version.
 
         It's Neptune Run's short_id
+
         """
         return self._run_short_id
