@@ -25,10 +25,11 @@ log = logging.getLogger(__name__)
 
 
 class AdvancedProfiler(Profiler):
-    """This profiler uses Python's cProfiler to record more detailed information about time spent in each function
-    call recorded during a given action.
+    """This profiler uses Python's cProfiler to record more detailed information about time spent in each function call
+    recorded during a given action.
 
     The output is quite verbose and you should only use this if you want very detailed reports.
+
     """
 
     def __init__(
@@ -87,5 +88,5 @@ class AdvancedProfiler(Profiler):
         return (
             self.__class__,
             (),
-            dict(dirpath=self.dirpath, filename=self.filename, line_count_restriction=self.line_count_restriction),
+            {"dirpath": self.dirpath, "filename": self.filename, "line_count_restriction": self.line_count_restriction},
         )
