@@ -45,8 +45,7 @@ _PROFILER = Union[torch.profiler.profile, torch.autograd.profiler.profile, torch
 
 
 class RegisterRecordFunction:
-    """While profiling autograd operations, this class will add labels for module names around the forward
-    function.
+    """While profiling autograd operations, this class will add labels for module names around the forward function.
 
     The Lightning PyTorch Profiler will activate this feature automatically. It can be deactivated as follows:
 
@@ -61,6 +60,7 @@ class RegisterRecordFunction:
         from lightning.pytorch import Trainer, seed_everything
         with RegisterRecordFunction(model):
             out = model(batch)
+
     """
 
     def __init__(self, model: nn.Module) -> None:
@@ -216,7 +216,6 @@ class ScheduleWrapper:
 
 
 class PyTorchProfiler(Profiler):
-
     STEP_FUNCTIONS = {"training_step", "validation_step", "test_step", "predict_step"}
     AVAILABLE_SORT_KEYS = {
         "cpu_time",
@@ -287,6 +286,7 @@ class PyTorchProfiler(Profiler):
                 If arg ``sort_by_key`` is not present in ``AVAILABLE_SORT_KEYS``.
                 If arg ``schedule`` is not a ``Callable``.
                 If arg ``schedule`` does not return a ``torch.profiler.ProfilerAction``.
+
         """
         super().__init__(dirpath=dirpath, filename=filename)
 
@@ -369,6 +369,7 @@ class PyTorchProfiler(Profiler):
         if _KINETO_AVAILABLE:
             # Those schedule defaults allow the profiling overhead to be negligible over training time.
             return torch.profiler.schedule(wait=1, warmup=1, active=3)
+        return None
 
     def _default_activities(self) -> List["ProfilerActivity"]:
         activities: List["ProfilerActivity"] = []
