@@ -32,8 +32,8 @@ _TABLE_DATA = List[_TABLE_ROW]
 
 
 class SimpleProfiler(Profiler):
-    """This profiler simply records the duration of actions (in seconds) and reports the mean duration of each
-    action and the total time spent over the entire training run."""
+    """This profiler simply records the duration of actions (in seconds) and reports the mean duration of each action
+    and the total time spent over the entire training run."""
 
     def __init__(
         self,
@@ -100,9 +100,8 @@ class SimpleProfiler(Profiler):
         output_string += f"Profiler Report{sep}"
 
         if self.extended:
-
             if len(self.recorded_durations) > 0:
-                max_key = max(len(k) for k in self.recorded_durations.keys())
+                max_key = max(len(k) for k in self.recorded_durations)
 
                 def log_row_extended(action: str, mean: str, num_calls: str, total: str, per: str) -> str:
                     row = f"{sep}|  {action:<{max_key}s}\t|  {mean:<15}\t|"
