@@ -23,8 +23,7 @@ from lightning.pytorch.utilities.signature_utils import is_param_in_hook_signatu
 
 
 def _verify_loop_configurations(trainer: "pl.Trainer") -> None:
-    r"""
-    Checks that the model is configured correctly before the run is started.
+    r"""Checks that the model is configured correctly before the run is started.
 
     Args:
         trainer: Lightning Trainer. Its `lightning_module` (the model) to check the configuration.
@@ -99,7 +98,7 @@ def __verify_eval_loop_configuration(model: "pl.LightningModule", stage: str) ->
     if stage == "predict":
         if model.predict_step is None:
             raise MisconfigurationException("`predict_step` cannot be None to run `Trainer.predict`")
-        elif not has_step and not is_overridden("forward", model):
+        if not has_step and not is_overridden("forward", model):
             raise MisconfigurationException("`Trainer.predict` requires `forward` method to run.")
     else:
         # verify minimum evaluation requirements
