@@ -18,7 +18,6 @@
 # WE FAVOR READABILITY OVER ENGINEERING-CONSTRUCTS BY DESIGN
 # DO NOT REMOVE THIS NOTICE
 # - WILLIAM FALCON
-
 """Trainer to automate the training."""
 import logging
 import math
@@ -130,8 +129,7 @@ class Trainer:
         reload_dataloaders_every_n_epochs: int = 0,
         default_root_dir: Optional[_PATH] = None,
     ) -> None:
-        r"""
-        Customize every aspect of training via flags.
+        r"""Customize every aspect of training via flags.
 
         Args:
             accelerator: Supports passing different accelerator types ("cpu", "gpu", "tpu", "ipu", "hpu", "mps", "auto")
@@ -280,7 +278,6 @@ class Trainer:
                 :paramref:`~lightning.pytorch.trainer.trainer.Trainer.profiler`,
                 :meth:`~lightning.pytorch.core.module.LightningModule.log`,
                 :meth:`~lightning.pytorch.core.module.LightningModule.log_dict`.
-
             plugins: Plugins allow modification of core behavior like ddp and amp, and enable custom lightning plugins.
                 Default: ``None``.
 
@@ -293,6 +290,15 @@ class Trainer:
             default_root_dir: Default path for logs and weights when no logger/ckpt_callback passed.
                 Default: ``os.getcwd()``.
                 Can be remote file paths such as `s3://mybucket/path` or 'hdfs://path/'
+
+        Raises:
+            TypeError:
+                If ``gradient_clip_val`` is not an int or float.
+
+            MisconfigurationException:
+                If ``gradient_clip_algorithm`` is invalid.
+                If ``track_grad_norm`` is not a positive number or inf.
+
         """
         super().__init__()
         log.debug(f"{self.__class__.__name__}: Initializing trainer with parameters: {locals()}")
@@ -494,29 +500,35 @@ class Trainer:
         datamodule: Optional[LightningDataModule] = None,
         ckpt_path: Optional[str] = None,
     ) -> None:
-        r"""
-        Runs the full optimization routine.
+        r"""Runs the full optimization routine.
 
         Args:
             model: Model to fit.
 
             train_dataloaders: An iterable or collection of iterables specifying training samples.
                 Alternatively, a :class:`~lightning.pytorch.core.datamodule.LightningDataModule` that defines
-                the `:class:`~lightning.pytorch.core.hooks.DataHooks.train_dataloader` hook.
+                the :class:`~lightning.pytorch.core.hooks.DataHooks.train_dataloader` hook.
 
             val_dataloaders: An iterable or collection of iterables specifying validation samples.
 
+            datamodule: A :class:`~lightning.pytorch.core.datamodule.LightningDataModule` that defines
+                the :class:`~lightning.pytorch.core.hooks.DataHooks.train_dataloader` hook.
+
             ckpt_path: Path/URL of the checkpoint from which training is resumed. Could also be one of two special
                 keywords ``"last"`` and ``"hpc"``. If there is no checkpoint file at the path, an exception is raised.
-                If resuming from mid-epoch checkpoint, training will start from the beginning of the next epoch.
 
-            datamodule: A :class:`~lightning.pytorch.core.datamodule.LightningDataModule` that defines
-                the `:class:`~lightning.pytorch.core.hooks.DataHooks.train_dataloader` hook.
+        Raises:
+            TypeError:
+                If ``model`` is not :class:`~lightning.pytorch.core.module.LightningModule` for torch version less than
+                2.0.0 and if ``model`` is not :class:`~lightning.pytorch.core.module.LightningModule` or
+                :class:`torch._dynamo.OptimizedModule` for torch versions greater than or equal to 2.0.0 .
 
         For more information about multiple dataloaders, see this :ref:`section <multiple-dataloaders>`.
+
         """
         model = _maybe_unwrap_optimized(model)
         self.strategy._lightning_module = model
+        _verify_strategy_supports_compile(model, self.strategy)
         call._call_and_handle_interrupt(
             self, self._fit_impl, model, train_dataloaders, val_dataloaders, datamodule, ckpt_path
         )
@@ -570,15 +582,14 @@ class Trainer:
         verbose: bool = True,
         datamodule: Optional[LightningDataModule] = None,
     ) -> _EVALUATE_OUTPUT:
-        r"""
-        Perform one evaluation epoch over the validation set.
+        r"""Perform one evaluation epoch over the validation set.
 
         Args:
             model: The model to validate.
 
             dataloaders: An iterable or collection of iterables specifying validation samples.
                 Alternatively, a :class:`~lightning.pytorch.core.datamodule.LightningDataModule` that defines
-                the `:class:`~lightning.pytorch.core.hooks.DataHooks.val_dataloader` hook.
+                the :class:`~lightning.pytorch.core.hooks.DataHooks.val_dataloader` hook.
 
             ckpt_path: Either ``"best"``, ``"last"``, ``"hpc"`` or path to the checkpoint you wish to validate.
                 If ``None`` and the model instance was passed, use the current weights.
@@ -588,7 +599,7 @@ class Trainer:
             verbose: If True, prints the validation results.
 
             datamodule: A :class:`~lightning.pytorch.core.datamodule.LightningDataModule` that defines
-                the `:class:`~lightning.pytorch.core.hooks.DataHooks.val_dataloader` hook.
+                the :class:`~lightning.pytorch.core.hooks.DataHooks.val_dataloader` hook.
 
         For more information about multiple dataloaders, see this :ref:`section <multiple-dataloaders>`.
 
@@ -596,6 +607,18 @@ class Trainer:
             List of dictionaries with metrics logged during the validation phase, e.g., in model- or callback hooks
             like :meth:`~lightning.pytorch.LightningModule.validation_step` etc.
             The length of the list corresponds to the number of validation dataloaders used.
+
+        Raises:
+            TypeError:
+                If no ``model`` is passed and there was no ``LightningModule`` passed in the previous run.
+                If ``model`` passed is not `LightningModule` or `torch._dynamo.OptimizedModule`.
+
+            MisconfigurationException:
+                If both ``dataloaders`` and ``datamodule`` are passed. Pass only one of these.
+
+            RuntimeError:
+                If a compiled ``model`` is passed and the strategy is not supported.
+
         """
         if model is None:
             # do we still have a reference from a previous call?
@@ -606,6 +629,7 @@ class Trainer:
         else:
             model = _maybe_unwrap_optimized(model)
             self.strategy._lightning_module = model
+        _verify_strategy_supports_compile(self.lightning_module, self.strategy)
         return call._call_and_handle_interrupt(
             self, self._validate_impl, model, dataloaders, ckpt_path, verbose, datamodule
         )
@@ -666,16 +690,15 @@ class Trainer:
         verbose: bool = True,
         datamodule: Optional[LightningDataModule] = None,
     ) -> _EVALUATE_OUTPUT:
-        r"""
-        Perform one evaluation epoch over the test set.
-        It's separated from fit to make sure you never run on your test set until you want to.
+        r"""Perform one evaluation epoch over the test set. It's separated from fit to make sure you never run on your
+        test set until you want to.
 
         Args:
             model: The model to test.
 
             dataloaders: An iterable or collection of iterables specifying test samples.
                 Alternatively, a :class:`~lightning.pytorch.core.datamodule.LightningDataModule` that defines
-                the `:class:`~lightning.pytorch.core.hooks.DataHooks.test_dataloader` hook.
+                the :class:`~lightning.pytorch.core.hooks.DataHooks.test_dataloader` hook.
 
             ckpt_path: Either ``"best"``, ``"last"``, ``"hpc"`` or path to the checkpoint you wish to test.
                 If ``None`` and the model instance was passed, use the current weights.
@@ -685,7 +708,7 @@ class Trainer:
             verbose: If True, prints the test results.
 
             datamodule: A :class:`~lightning.pytorch.core.datamodule.LightningDataModule` that defines
-                the `:class:`~lightning.pytorch.core.hooks.DataHooks.test_dataloader` hook.
+                the :class:`~lightning.pytorch.core.hooks.DataHooks.test_dataloader` hook.
 
         For more information about multiple dataloaders, see this :ref:`section <multiple-dataloaders>`.
 
@@ -693,6 +716,18 @@ class Trainer:
             List of dictionaries with metrics logged during the test phase, e.g., in model- or callback hooks
             like :meth:`~lightning.pytorch.LightningModule.test_step` etc.
             The length of the list corresponds to the number of test dataloaders used.
+
+        Raises:
+            TypeError:
+                If no ``model`` is passed and there was no ``LightningModule`` passed in the previous run.
+                If ``model`` passed is not `LightningModule` or `torch._dynamo.OptimizedModule`.
+
+            MisconfigurationException:
+                If both ``dataloaders`` and ``datamodule`` are passed. Pass only one of these.
+
+            RuntimeError:
+                If a compiled ``model`` is passed and the strategy is not supported.
+
         """
         if model is None:
             # do we still have a reference from a previous call?
@@ -703,6 +738,7 @@ class Trainer:
         else:
             model = _maybe_unwrap_optimized(model)
             self.strategy._lightning_module = model
+        _verify_strategy_supports_compile(self.lightning_module, self.strategy)
         return call._call_and_handle_interrupt(
             self, self._test_impl, model, dataloaders, ckpt_path, verbose, datamodule
         )
@@ -763,20 +799,18 @@ class Trainer:
         return_predictions: Optional[bool] = None,
         ckpt_path: Optional[str] = None,
     ) -> Optional[_PREDICT_OUTPUT]:
-        r"""
-        Run inference on your data.
-        This will call the model forward function to compute predictions. Useful to perform distributed
-        and batched predictions. Logging is disabled in the predict hooks.
+        r"""Run inference on your data. This will call the model forward function to compute predictions. Useful to
+        perform distributed and batched predictions. Logging is disabled in the predict hooks.
 
         Args:
             model: The model to predict with.
 
             dataloaders: An iterable or collection of iterables specifying predict samples.
                 Alternatively, a :class:`~lightning.pytorch.core.datamodule.LightningDataModule` that defines
-                the `:class:`~lightning.pytorch.core.hooks.DataHooks.predict_dataloader` hook.
+                the :class:`~lightning.pytorch.core.hooks.DataHooks.predict_dataloader` hook.
 
             datamodule: A :class:`~lightning.pytorch.core.datamodule.LightningDataModule` that defines
-                the `:class:`~lightning.pytorch.core.hooks.DataHooks.predict_dataloader` hook.
+                the :class:`~lightning.pytorch.core.hooks.DataHooks.predict_dataloader` hook.
 
             return_predictions: Whether to return predictions.
                 ``True`` by default except when an accelerator that spawns processes is used (not supported).
@@ -791,7 +825,19 @@ class Trainer:
         Returns:
             Returns a list of dictionaries, one for each provided dataloader containing their respective predictions.
 
+        Raises:
+            TypeError:
+                If no ``model`` is passed and there was no ``LightningModule`` passed in the previous run.
+                If ``model`` passed is not `LightningModule` or `torch._dynamo.OptimizedModule`.
+
+            MisconfigurationException:
+                If both ``dataloaders`` and ``datamodule`` are passed. Pass only one of these.
+
+            RuntimeError:
+                If a compiled ``model`` is passed and the strategy is not supported.
+
         See :ref:`Lightning inference section<deploy/production_basic:Predict step with your LightningModule>` for more.
+
         """
         if model is None:
             # do we still have a reference from a previous call?
@@ -802,6 +848,7 @@ class Trainer:
         else:
             model = _maybe_unwrap_optimized(model)
             self.strategy._lightning_module = model
+        _verify_strategy_supports_compile(self.lightning_module, self.strategy)
         return call._call_and_handle_interrupt(
             self, self._predict_impl, model, dataloaders, datamodule, return_predictions, ckpt_path
         )
@@ -854,8 +901,6 @@ class Trainer:
     def _run(
         self, model: "pl.LightningModule", ckpt_path: Optional[_PATH] = None
     ) -> Optional[Union[_EVALUATE_OUTPUT, _PREDICT_OUTPUT]]:
-        _verify_strategy_supports_compile(model, self.strategy)
-
         if self.state.fn == TrainerFn.FITTING:
             min_epochs, max_epochs = _parse_loop_limits(
                 self.min_steps, self.max_steps, self.min_epochs, self.max_epochs, self
@@ -1034,8 +1079,7 @@ class Trainer:
 
     @property
     def strategy(self) -> Strategy:
-        # TODO(fabric): remove ignore after merging Fabric and PL strategies
-        return self._accelerator_connector.strategy  # type: ignore[return-value]
+        return self._accelerator_connector.strategy
 
     @property
     def precision_plugin(self) -> PrecisionPlugin:
@@ -1117,6 +1161,7 @@ class Trainer:
 
         To access the pure LightningModule, use
         :meth:`~lightning.pytorch.trainer.trainer.Trainer.lightning_module` instead.
+
         """
         return self.strategy.model
 
@@ -1128,11 +1173,13 @@ class Trainer:
     def log_dir(self) -> Optional[str]:
         """The directory for the current experiment. Use this to save images to, etc...
 
-        .. code-block:: python
+        .. note:: You must call this on all processes. Failing to do so will cause your program to stall forever.
 
-            def training_step(self, batch, batch_idx):
-                img = ...
-                save_img(img, self.trainer.log_dir)
+         .. code-block:: python
+
+             def training_step(self, batch, batch_idx):
+                 img = ...
+                 save_img(img, self.trainer.log_dir)
         """
         if len(self.loggers) > 0:
             if not isinstance(self.loggers[0], TensorBoardLogger):
@@ -1154,6 +1201,7 @@ class Trainer:
             def training_step(self, batch, batch_idx):
                 if self.trainer.is_global_zero:
                     print("in node 0, accelerator 0")
+
         """
         return self.strategy.is_global_zero
 
@@ -1161,6 +1209,7 @@ class Trainer:
     def distributed_sampler_kwargs(self) -> Optional[Dict[str, Any]]:
         if isinstance(self.strategy, ParallelStrategy):
             return self.strategy.distributed_sampler_kwargs
+        return None
 
     @property
     def enable_validation(self) -> bool:
@@ -1176,6 +1225,7 @@ class Trainer:
         """The default location to save artifacts of loggers, checkpoints etc.
 
         It is used as a fallback if logger or checkpoint callback do not define specific save paths.
+
         """
         if get_filesystem(self._default_root_dir).protocol == "file":
             return os.path.normpath(self._default_root_dir)
@@ -1238,6 +1288,7 @@ class Trainer:
             # you will be in charge of resetting this
             trainer.ckpt_path = None
             trainer.test(model)
+
         """
         self._checkpoint_connector._ckpt_path = ckpt_path
         self._checkpoint_connector._user_managed = bool(ckpt_path)
@@ -1245,14 +1296,17 @@ class Trainer:
     def save_checkpoint(
         self, filepath: _PATH, weights_only: bool = False, storage_options: Optional[Any] = None
     ) -> None:
-        r"""
-        Runs routine to create a checkpoint.
+        r"""Runs routine to create a checkpoint.
 
         Args:
             filepath: Path where checkpoint is saved.
             weights_only: If ``True``, will only save the model weights.
             storage_options: parameter for how to save to storage, passed to ``CheckpointIO`` plugin
 
+        Raises:
+            AttributeError:
+                If the model is not attached to the Trainer before calling this method.
+
         """
         if self.model is None:
             raise AttributeError(
@@ -1319,6 +1373,11 @@ class Trainer:
 
     @property
     def sanity_checking(self) -> bool:
+        """Whether sanity checking is running.
+
+        Useful to disable some hooks, logging or callbacks during the sanity checking.
+
+        """
         return self.state.stage == RunningStage.SANITY_CHECKING
 
     @sanity_checking.setter
@@ -1345,6 +1404,7 @@ class Trainer:
         """The number of optimizer steps taken (does not reset each epoch).
 
         This includes multiple optimizers (if enabled).
+
         """
         return self.fit_loop.epoch_loop.global_step
 
@@ -1379,26 +1439,30 @@ class Trainer:
         """The training dataloader(s) used during ``trainer.fit()``."""
         if (combined_loader := self.fit_loop._combined_loader) is not None:
             return combined_loader.iterables
+        return None
 
     @property
     def val_dataloaders(self) -> Optional[EVAL_DATALOADERS]:
         """The validation dataloader(s) used during ``trainer.fit()`` or ``trainer.validate()``."""
-        if (combined_loader := self.fit_loop.epoch_loop.val_loop._combined_loader) is not None:
-            return combined_loader.iterables
-        elif (combined_loader := self.validate_loop._combined_loader) is not None:
+        if (combined_loader := self.fit_loop.epoch_loop.val_loop._combined_loader) is not None or (
+            combined_loader := self.validate_loop._combined_loader
+        ) is not None:
             return combined_loader.iterables
+        return None
 
     @property
     def test_dataloaders(self) -> Optional[EVAL_DATALOADERS]:
         """The test dataloader(s) used during ``trainer.test()``."""
         if (combined_loader := self.test_loop._combined_loader) is not None:
             return combined_loader.iterables
+        return None
 
     @property
     def predict_dataloaders(self) -> Optional[EVAL_DATALOADERS]:
         """The prediction dataloader(s) used during ``trainer.predict()``."""
         if (combined_loader := self.predict_loop._combined_loader) is not None:
             return combined_loader.iterables
+        return None
 
     @property
     def num_training_batches(self) -> Union[int, float]:
@@ -1450,6 +1514,7 @@ class Trainer:
             return self._evaluation_loop
         if self.predicting:
             return self.predict_loop
+        return None
 
     """
     Logging properties
@@ -1469,9 +1534,9 @@ class Trainer:
 
     @property
     def loggers(self) -> List[Logger]:
-        """The list of class:`~lightning.pytorch.loggers.logger.Logger` used.
+        """The list of :class:`~lightning.pytorch.loggers.logger.Logger` used.
 
-        ..code-block:: python
+        .. code-block:: python
 
             for logger in trainer.loggers:
                 logger.log_metrics({"foo": 1.0})
@@ -1486,15 +1551,15 @@ class Trainer:
     def callback_metrics(self) -> _OUT_DICT:
         """The metrics available to callbacks.
 
-        This includes metrics logged via :meth:`~lightning.pytorch.core.module.LightningModule.log`.
-
-        ..code-block:: python
+        .. code-block:: python
 
             def training_step(self, batch, batch_idx):
                 self.log("a_val", 2.0)
 
+
             callback_metrics = trainer.callback_metrics
             assert callback_metrics["a_val"] == 2.0
+
         """
         return self._logger_connector.callback_metrics
 
@@ -1504,6 +1569,7 @@ class Trainer:
 
         This includes metrics logged via :meth:`~lightning.pytorch.core.module.LightningModule.log` with the
         :paramref:`~lightning.pytorch.core.module.LightningModule.log.logger` argument set.
+
         """
         return self._logger_connector.logged_metrics
 
@@ -1513,6 +1579,7 @@ class Trainer:
 
         This includes metrics logged via :meth:`~lightning.pytorch.core.module.LightningModule.log` with the
         :paramref:`~lightning.pytorch.core.module.LightningModule.log.prog_bar` argument set.
+
         """
         return self._logger_connector.progress_bar_metrics
 
@@ -1521,6 +1588,7 @@ class Trainer:
         active_loop = self._active_loop
         if active_loop is not None:
             return active_loop._results
+        return None
 
     """
     Other
@@ -1534,13 +1602,18 @@ class Trainer:
         This accounts for gradient accumulation and the current trainer configuration. This might sets up your training
         dataloader if hadn't been set up already.
 
-        ..code-block:: python
+        .. code-block:: python
 
             def configure_optimizers(self):
                 optimizer = ...
                 stepping_batches = self.trainer.estimated_stepping_batches
                 scheduler = torch.optim.lr_scheduler.OneCycleLR(optimizer, max_lr=1e-3, total_steps=stepping_batches)
                 return [optimizer], [scheduler]
+
+        Raises:
+            MisconfigurationException:
+                If estimated stepping batches cannot be computed due to different `accumulate_grad_batches`
+                at different epochs.
         """
         # infinite training
         if self.max_epochs == -1:
