@@ -39,8 +39,8 @@ class Tuner:
         max_trials: int = 25,
         batch_arg_name: str = "batch_size",
     ) -> Optional[int]:
-        """Iteratively try to find the largest batch size for a given model that does not give an out of memory
-        (OOM) error.
+        """Iteratively try to find the largest batch size for a given model that does not give an out of memory (OOM)
+        error.
 
         Args:
             model: Model to tune.
@@ -71,6 +71,7 @@ class Tuner:
                 - ``model``
                 - ``model.hparams``
                 - ``trainer.datamodule`` (the datamodule passed to the tune method)
+
         """
         _check_tuner_configuration(train_dataloaders, val_dataloaders, dataloaders, method)
         _check_scale_batch_size_configuration(self._trainer)
@@ -113,7 +114,7 @@ class Tuner:
         max_lr: float = 1,
         num_training: int = 100,
         mode: str = "exponential",
-        early_stop_threshold: float = 4.0,
+        early_stop_threshold: Optional[float] = 4.0,
         update_attr: bool = True,
         attr_name: str = "",
     ) -> Optional["pl.tuner.lr_finder._LRFinder"]:
@@ -149,6 +150,7 @@ class Tuner:
             MisconfigurationException:
                 If learning rate/lr in ``model`` or ``model.hparams`` isn't overridden,
                 or if you are using more than one optimizer.
+
         """
         if method != "fit":
             raise MisconfigurationException("method='fit' is an invalid configuration to run lr finder.")
