@@ -34,8 +34,8 @@ UNKNOWN_SIZE = "?"
 
 
 class LayerSummary:
-    """Summary class for a single layer in a :class:`~lightning.pytorch.core.module.LightningModule`. It collects
-    the following information:
+    """Summary class for a single layer in a :class:`~lightning.pytorch.core.module.LightningModule`. It collects the
+    following information:
 
     - Type of the layer (e.g. Linear, BatchNorm1d, ...)
     - Input shape
@@ -61,6 +61,7 @@ class LayerSummary:
 
     Args:
         module: A module to summarize
+
     """
 
     def __init__(self, module: nn.Module) -> None:
@@ -74,13 +75,13 @@ class LayerSummary:
         self.detach_hook()
 
     def _register_hook(self) -> Optional[RemovableHandle]:
-        """Registers a hook on the module that computes the input- and output size(s) on the first forward pass. If
-        the hook is called, it will remove itself from the from the module, meaning that recursive models will only
-        record their input- and output shapes once. Registering hooks on :class:`~torch.jit.ScriptModule` is not
-        supported.
+        """Registers a hook on the module that computes the input- and output size(s) on the first forward pass. If the
+        hook is called, it will remove itself from the from the module, meaning that recursive models will only record
+        their input- and output shapes once. Registering hooks on :class:`~torch.jit.ScriptModule` is not supported.
 
         Return:
             A handle for the installed hook, or ``None`` if registering the hook is not possible.
+
         """
 
         def hook(_: nn.Module, inp: Any, out: Any) -> None:
@@ -100,6 +101,7 @@ class LayerSummary:
         """Removes the forward hook if it was not already removed in the forward pass.
 
         Will be called after the summary is created.
+
         """
         if self._hook_handle is not None:
             self._hook_handle.remove()
@@ -177,6 +179,7 @@ class ModelSummary:
         0         Non-trainable params
         132 K     Total params
         0.530     Total estimated model params size (MB)
+
     """
 
     def __init__(self, model: "pl.LightningModule", max_depth: int = 1) -> None:
@@ -282,6 +285,7 @@ class ModelSummary:
         """Makes a summary listing with:
 
         Layer Name, Layer Type, Number of Parameters, Input Sizes, Output Sizes, Model Size
+
         """
         arrays = [
             (" ", list(map(str, range(len(self._layer_summary))))),
@@ -313,8 +317,7 @@ def parse_batch_shape(batch: Any) -> Union[str, List]:
         return list(batch.shape)
 
     if isinstance(batch, (list, tuple)):
-        shape = [parse_batch_shape(el) for el in batch]
-        return shape
+        return [parse_batch_shape(el) for el in batch]
 
     return UNKNOWN_SIZE
 
@@ -325,8 +328,8 @@ def _format_summary_table(
     model_size: float,
     *cols: Tuple[str, List[str]],
 ) -> str:
-    """Takes in a number of arrays, each specifying a column in the summary table, and combines them all into one
-    big string defining the summary table that are nicely formatted."""
+    """Takes in a number of arrays, each specifying a column in the summary table, and combines them all into one big
+    string defining the summary table that are nicely formatted."""
     n_rows = len(cols[0][1])
     n_cols = 1 + len(cols)
 
@@ -389,6 +392,7 @@ def get_human_readable_count(number: int) -> str:
 
     Return:
         A string formatted according to the pattern described above.
+
     """
     assert number >= 0
     labels = PARAMETER_NUM_UNITS
@@ -427,5 +431,6 @@ def summarize(lightning_module: "pl.LightningModule", max_depth: int = 1) -> Mod
 
     Return:
         The model summary object
+
     """
     return ModelSummary(lightning_module, max_depth=max_depth)
