@@ -28,11 +28,10 @@ from lightning.pytorch.utilities.rank_zero import rank_zero_warn
 
 def is_picklable(obj: object) -> bool:
     """Tests if an object can be pickled."""
-
     try:
         pickle.dumps(obj)
         return True
-    except (pickle.PickleError, AttributeError, RuntimeError):
+    except (pickle.PickleError, AttributeError, RuntimeError, TypeError):
         return False
 
 
@@ -94,7 +93,7 @@ def _get_init_args(frame: types.FrameType) -> Tuple[Optional[Any], Dict[str, Any
     filtered_vars = [n for n in (self_var, args_var, kwargs_var) if n]
     exclude_argnames = (*filtered_vars, "__class__", "frame", "frame_args")
     # only collect variables that appear in the signature
-    local_args = {k: local_vars[k] for k in init_parameters.keys()}
+    local_args = {k: local_vars[k] for k in init_parameters}
     # kwargs_var might be None => raised an error by mypy
     if kwargs_var:
         local_args.update(local_args.get(kwargs_var, {}))
@@ -121,6 +120,7 @@ def collect_init_args(
           A list of dictionaries where each dictionary contains the arguments passed to the
           constructor at that level. The last entry corresponds to the constructor call of the
           most specific class in the hierarchy.
+
     """
     _, _, _, local_vars = inspect.getargvalues(frame)
     # frame.f_back must be of a type types.FrameType for get_init_args/collect_init_args due to mypy
@@ -217,6 +217,7 @@ class AttributeDict(Dict):
     "key2":    abc
     "my-key":  3.14
     "new_key": 42
+
     """
 
     def __getattr__(self, key: str) -> Optional[Any]:
@@ -234,8 +235,7 @@ class AttributeDict(Dict):
         max_key_length = max(len(str(k)) for k in self)
         tmp_name = "{:" + str(max_key_length + 3) + "s} {}"
         rows = [tmp_name.format(f'"{n}":', self[n]) for n in sorted(self.keys())]
-        out = "\n".join(rows)
-        return out
+        return "\n".join(rows)
 
 
 def _lightning_get_all_attr_holders(model: "pl.LightningModule", attribute: str) -> List[Any]:
@@ -243,6 +243,7 @@ def _lightning_get_all_attr_holders(model: "pl.LightningModule", attribute: str)
 
     Gets all of the objects or dicts that holds attribute. Checks for attribute in model namespace, the old hparams
     namespace/dict, and the datamodule.
+
     """
     holders: List[Any] = []
 
@@ -271,6 +272,7 @@ def _lightning_get_first_attr_holder(model: "pl.LightningModule", attribute: str
 
     Gets the object or dict that holds attribute, or None. Checks for attribute in model namespace, the old hparams
     namespace/dict, and the datamodule, returns the last one that has it.
+
     """
     holders = _lightning_get_all_attr_holders(model, attribute)
     if len(holders) == 0:
@@ -283,18 +285,20 @@ def lightning_hasattr(model: "pl.LightningModule", attribute: str) -> bool:
     """Special hasattr for Lightning.
 
     Checks for attribute in model namespace, the old hparams namespace/dict, and the datamodule.
+
     """
     return _lightning_get_first_attr_holder(model, attribute) is not None
 
 
 def lightning_getattr(model: "pl.LightningModule", attribute: str) -> Optional[Any]:
-    """Special getattr for Lightning. Checks for attribute in model namespace, the old hparams namespace/dict, and
-    the datamodule.
+    """Special getattr for Lightning. Checks for attribute in model namespace, the old hparams namespace/dict, and the
+    datamodule.
 
     Raises:
         AttributeError:
             If ``model`` doesn't have ``attribute`` in any of
             model namespace, the hparams namespace/dict, and the datamodule.
+
     """
     holder = _lightning_get_first_attr_holder(model, attribute)
     if holder is None:
@@ -309,13 +313,14 @@ def lightning_getattr(model: "pl.LightningModule", attribute: str) -> Optional[A
 
 
 def lightning_setattr(model: "pl.LightningModule", attribute: str, value: Any) -> None:
-    """Special setattr for Lightning. Checks for attribute in model namespace and the old hparams namespace/dict.
-    Will also set the attribute on datamodule, if it exists.
+    """Special setattr for Lightning. Checks for attribute in model namespace and the old hparams namespace/dict. Will
+    also set the attribute on datamodule, if it exists.
 
     Raises:
         AttributeError:
             If ``model`` doesn't have ``attribute`` in any of
             model namespace, the hparams namespace/dict, and the datamodule.
+
     """
     holders = _lightning_get_all_attr_holders(model, attribute)
     if len(holders) == 0:
